@@ -21,28 +21,42 @@
  */
 
 #include <stdio.h>
-#include "HtmlDocumentGenerator.h"
-#include "libwpd-stream.h"
-#include "libwpd.h"
+#include <librevenge-stream/librevenge-stream.h>
+#include <librevenge-generators/librevenge-generators.h>
+#include <libwpd/libwpd.h>
 #include <string.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifndef VERSION
+#define VERSION "UNKNOWN VERSION"
+#endif
+
+using namespace libwpd;
+
 namespace
 {
 
 int printUsage()
 {
-	printf("Usage: wpd2html [OPTION] <WordPerfect Document>\n");
+	printf("`wpd2html' converts WordPerfect documents to HTML.\n");
+	printf("\n");
+	printf("Usage: wpd2html [OPTION] FILE\n");
 	printf("\n");
 	printf("Options:\n");
-	printf("--help                Shows this help message\n");
-	printf("--password <password> Try to decrypt password protected document\n");
-	printf("--version             Output wpd2html version \n");
+	printf("\t--help                show this help message\n");
+	printf("\t--password PASSWORD   try to decrypt password protected document\n");
+	printf("\t--version             print version and exit\n");
+	printf("\n");
+	printf("Report bugs to <https://sourceforge.net/p/libwpd/tickets/> or <https://bugs.documentfoundation.org/>.\n");
 	return -1;
 }
 
 int printVersion()
 {
-	printf("wpd2html %s\n", LIBWPD_VERSION_STRING);
+	printf("wpd2html %s\n", VERSION);
 	return 0;
 }
 
@@ -76,7 +90,7 @@ int main(int argc, char *argv[])
 	if (!file)
 		return printUsage();
 
-	WPXFileStream input(file);
+	librevenge::RVNGFileStream input(file);
 
 	WPDConfidence confidence = WPDocument::isFileFormatSupported(&input);
 	if (confidence != WPD_CONFIDENCE_EXCELLENT && confidence != WPD_CONFIDENCE_SUPPORTED_ENCRYPTION)
@@ -97,7 +111,8 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	HtmlDocumentGenerator documentGenerator;
+	librevenge::RVNGString document;
+	librevenge::RVNGHTMLTextGenerator documentGenerator(document);
 	WPDResult error = WPDocument::parse(&input, &documentGenerator, password);
 
 	if (error == WPD_FILE_ACCESS_ERROR)
@@ -114,6 +129,8 @@ int main(int argc, char *argv[])
 	if (error != WPD_OK)
 		return 1;
 
+	printf("%s", document.cstr());
+
 	return 0;
 }
 /* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
