@@ -25,29 +25,43 @@
  */
 
 #include <stdio.h>
-#include "libwpd.h"
-#include "libwpd-stream.h"
-#include "RawDocumentGenerator.h"
+#include <librevenge-stream/librevenge-stream.h>
+#include <librevenge-generators/librevenge-generators.h>
+#include <libwpd/libwpd.h>
 #include <string.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifndef VERSION
+#define VERSION "UNKNOWN VERSION"
+#endif
+
+using namespace libwpd;
+
 namespace
 {
 
 int printUsage()
 {
-	printf("Usage: wpd2raw [OPTION] <WordPerfect Document>\n");
+	printf("`wpd2raw' is used to test libwpd.\n");
+	printf("\n");
+	printf("Usage: wpd2raw [OPTION] FILE\n");
 	printf("\n");
 	printf("Options:\n");
-	printf("--callgraph           Display the call graph nesting level\n");
-	printf("--help                Shows this help message\n");
-	printf("--password <password> Try to decrypt password protected document\n");
-	printf("--version             Output wpd2raw version \n");
+	printf("\t--callgraph           display the call graph nesting level\n");
+	printf("\t--help                show this help message\n");
+	printf("\t--password PASSWORD	try to decrypt password protected document\n");
+	printf("\t--version             print version and exit\n");
+	printf("\n");
+	printf("Report bugs to <https://sourceforge.net/p/libwpd/tickets/> or <https://bugs.documentfoundation.org/>.\n");
 	return -1;
 }
 
 int printVersion()
 {
-	printf("wpd2raw %s\n", LIBWPD_VERSION_STRING);
+	printf("wpd2raw %s\n", VERSION);
 	return 0;
 }
 
@@ -84,7 +98,7 @@ int main(int argc, char *argv[])
 	if (!file)
 		return printUsage();
 
-	WPXFileStream input(file);
+	librevenge::RVNGFileStream input(file);
 
 	WPDConfidence confidence = WPDocument::isFileFormatSupported(&input);
 	if (confidence != WPD_CONFIDENCE_EXCELLENT && confidence != WPD_CONFIDENCE_SUPPORTED_ENCRYPTION)
@@ -105,7 +119,7 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	RawDocumentGenerator documentGenerator(printIndentLevel);
+	librevenge::RVNGRawTextGenerator documentGenerator(printIndentLevel);
 	WPDResult error = WPDocument::parse(&input, &documentGenerator, password);
 
 	if (error == WPD_FILE_ACCESS_ERROR)
