@@ -1,21 +1,22 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003-2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2005-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,7 +32,7 @@
 
 // #define WP1_NUM_TEXT_COLUMS_PER_INCH 12
 
-_WP1ContentParsingState::_WP1ContentParsingState() :
+WP1ContentParsingState::WP1ContentParsingState() :
 	m_textBuffer(),
 	m_numDeferredTabs(0),
 	m_footNoteNumber(0),
@@ -39,12 +40,12 @@ _WP1ContentParsingState::_WP1ContentParsingState() :
 {
 }
 
-_WP1ContentParsingState::~_WP1ContentParsingState()
+WP1ContentParsingState::~WP1ContentParsingState()
 {
 }
 
 
-WP1ContentListener::WP1ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP1SubDocument *> &subDocuments, WPXDocumentInterface *documentInterface) :
+WP1ContentListener::WP1ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP1SubDocument *> &subDocuments, librevenge::RVNGTextInterface *documentInterface) :
 	WP1Listener(),
 	WPXContentListener(pageList, documentInterface),
 	m_parseState(new WP1ContentParsingState),
@@ -54,42 +55,42 @@ WP1ContentListener::WP1ContentListener(std::list<WPXPageSpan> &pageList, std::ve
 	m_ps->m_fontSize = 12.0;
 }
 
-WP1ContentListener::~WP1ContentListener() 
+WP1ContentListener::~WP1ContentListener()
 {
 	delete m_parseState;
 }
 
 
-void WP1ContentListener::insertCharacter(uint16_t character)
+void WP1ContentListener::insertCharacter(unsigned character)
 {
 	if (!isUndoOn())
 	{
-		uint16_t tmpCharacter = _mapNonUnicodeCharacter(character);
+		unsigned tmpCharacter = _mapNonUnicodeCharacter(character);
 
 		if (!m_ps->m_isSpanOpened)
 			_openSpan();
-		for (;m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
+		for (; m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
 		{
 			m_documentInterface->insertTab();
 		}
-		appendUCS4(m_parseState->m_textBuffer, (uint32_t)tmpCharacter);
+		appendUCS4(m_parseState->m_textBuffer, tmpCharacter);
 	}
 }
 
-void WP1ContentListener::insertExtendedCharacter(uint8_t extendedCharacter)
+void WP1ContentListener::insertExtendedCharacter(unsigned char extendedCharacter)
 {
 	if (!isUndoOn())
 	{
 		if (!m_ps->m_isSpanOpened)
 			_openSpan();
-		for (;m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
+		for (; m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
 		{
 			m_documentInterface->insertTab();
 		}
 		if (extendedCharacter <= 0x20)
-			appendUCS4(m_parseState->m_textBuffer, (uint32_t)0x20);
+			appendUCS4(m_parseState->m_textBuffer, (unsigned)0x20);
 		else
-			appendUCS4(m_parseState->m_textBuffer, (uint32_t)(_mapNonUnicodeCharacter(macintoshCharacterMap[extendedCharacter - 0x20])));
+			appendUCS4(m_parseState->m_textBuffer, (unsigned)(_mapNonUnicodeCharacter(macRomanCharacterMap[extendedCharacter - 0x20])));
 	}
 }
 
@@ -117,7 +118,7 @@ void WP1ContentListener::insertEOL()
 	{
 		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 			_openSpan();
-		for (;m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
+		for (; m_parseState->m_numDeferredTabs > 0; m_parseState->m_numDeferredTabs--)
 		{
 			m_documentInterface->insertTab();
 		}
@@ -143,16 +144,16 @@ void WP1ContentListener::insertNote(const WPXNoteType noteType, WP1SubDocument *
 
 		m_ps->m_isNote = true;
 
-		WPXPropertyList propList;
+		librevenge::RVNGPropertyList propList;
 
 		if (noteType == FOOTNOTE)
 		{
-			propList.insert("libwpd:number", ++(m_parseState->m_footNoteNumber));
+			propList.insert("librevenge:number", ++(m_parseState->m_footNoteNumber));
 			m_documentInterface->openFootnote(propList);
 		}
 		else
 		{
-			propList.insert("libwpd:number", ++(m_parseState->m_endNoteNumber));
+			propList.insert("librevenge:number", ++(m_parseState->m_endNoteNumber));
 			m_documentInterface->openEndnote(propList);
 		}
 
@@ -168,11 +169,11 @@ void WP1ContentListener::insertNote(const WPXNoteType noteType, WP1SubDocument *
 }
 
 
-void WP1ContentListener::attributeChange(bool isOn, uint8_t attribute)
+void WP1ContentListener::attributeChange(bool isOn, unsigned char attribute)
 {
 	_closeSpan();
 
-	uint32_t textAttributeBit = 0;
+	unsigned textAttributeBit = 0;
 
 	switch (attribute)
 	{
@@ -203,30 +204,32 @@ void WP1ContentListener::attributeChange(bool isOn, uint8_t attribute)
 	case WP1_ATTRIBUTE_UNDERLINE:
 		textAttributeBit = WPX_UNDERLINE_BIT;
 		break;
+	default:
+		break;
 	}
 
 	if (isOn)
 		m_ps->m_textAttributeBits |= textAttributeBit;
 	else
-		m_ps->m_textAttributeBits ^= textAttributeBit;
+		m_ps->m_textAttributeBits &= ~textAttributeBit;
 }
 
-void WP1ContentListener::fontPointSize(uint8_t pointSize)
+void WP1ContentListener::fontPointSize(unsigned char pointSize)
 {
 	if (!isUndoOn())
 	{
 		_closeSpan();
-		
+
 		m_ps->m_fontSize=double(pointSize);
 	}
 }
 
-void WP1ContentListener::fontId(uint16_t id)
+void WP1ContentListener::fontId(unsigned short id)
 {
 	if (!isUndoOn())
 	{
 		_closeSpan();
-		
+
 		switch (id)
 		{
 		case 0x0002:
@@ -382,7 +385,7 @@ void WP1ContentListener::fontId(uint16_t id)
 	}
 }
 
-void WP1ContentListener::marginReset(uint16_t leftMargin, uint16_t rightMargin)
+void WP1ContentListener::marginReset(unsigned short leftMargin, unsigned short rightMargin)
 {
 	if (!isUndoOn())
 	{
@@ -391,8 +394,8 @@ void WP1ContentListener::marginReset(uint16_t leftMargin, uint16_t rightMargin)
 			double leftMarginInch = (double)((double)leftMargin/72.0);
 			m_ps->m_leftMarginByPageMarginChange = leftMarginInch - m_ps->m_pageMarginLeft;
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-						+ m_ps->m_leftMarginByParagraphMarginChange
-						+ m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange
+			                              + m_ps->m_leftMarginByTabs;
 
 		}
 		if (rightMargin)
@@ -400,14 +403,14 @@ void WP1ContentListener::marginReset(uint16_t leftMargin, uint16_t rightMargin)
 			double rightMarginInch = (double)((double)rightMargin/72.0);
 			m_ps->m_rightMarginByPageMarginChange = rightMarginInch - m_ps->m_pageMarginRight;
 			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
-						+ m_ps->m_rightMarginByParagraphMarginChange
-						+ m_ps->m_rightMarginByTabs;
+			                               + m_ps->m_rightMarginByParagraphMarginChange
+			                               + m_ps->m_rightMarginByTabs;
 		}
 		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 	}
 }
 
-void WP1ContentListener::leftIndent(uint16_t leftMarginOffset)
+void WP1ContentListener::leftIndent(unsigned short leftMarginOffset)
 {
 	if (!isUndoOn())
 	{
@@ -418,14 +421,14 @@ void WP1ContentListener::leftIndent(uint16_t leftMarginOffset)
 			m_parseState->m_numDeferredTabs = 0;
 			m_ps->m_leftMarginByTabs += (double)((double)leftMarginOffset / 72.0);
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-						+ m_ps->m_leftMarginByParagraphMarginChange
-						+ m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange
+			                              + m_ps->m_leftMarginByTabs;
 		}
 		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 	}
 }
 
-void WP1ContentListener::leftRightIndent(uint16_t leftRightMarginOffset)
+void WP1ContentListener::leftRightIndent(unsigned short leftRightMarginOffset)
 {
 	if (!isUndoOn())
 	{
@@ -437,17 +440,17 @@ void WP1ContentListener::leftRightIndent(uint16_t leftRightMarginOffset)
 			m_ps->m_leftMarginByTabs += (double)((double)leftRightMarginOffset / 72.0);
 			m_ps->m_rightMarginByTabs += (double)((double)leftRightMarginOffset / 72.0);
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-						+ m_ps->m_leftMarginByParagraphMarginChange
-						+ m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange
+			                              + m_ps->m_leftMarginByTabs;
 			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
-						+ m_ps->m_rightMarginByParagraphMarginChange
-						+ m_ps->m_rightMarginByTabs;
+			                               + m_ps->m_rightMarginByParagraphMarginChange
+			                               + m_ps->m_rightMarginByTabs;
 		}
 		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 	}
 }
 
-void WP1ContentListener::leftMarginRelease(uint16_t release)
+void WP1ContentListener::leftMarginRelease(unsigned short release)
 {
 	if (!isUndoOn())
 	{
@@ -457,7 +460,7 @@ void WP1ContentListener::leftMarginRelease(uint16_t release)
 			{
 				m_ps->m_textIndentByTabs -= (double)((double)release / 72.0);
 				m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
-					+ m_ps->m_textIndentByTabs;
+				                              + m_ps->m_textIndentByTabs;
 			}
 			else
 				m_parseState->m_numDeferredTabs--;
@@ -466,15 +469,12 @@ void WP1ContentListener::leftMarginRelease(uint16_t release)
 	}
 }
 
-void WP1ContentListener::justificationChange(uint8_t justification)
+void WP1ContentListener::justificationChange(unsigned char justification)
 {
 	if (!isUndoOn())
 	{
 		switch (justification)
 		{
-		case 0x00:
-			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_LEFT;
-			break;
 		case 0x01:
 			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_CENTER;
 			break;
@@ -484,15 +484,18 @@ void WP1ContentListener::justificationChange(uint8_t justification)
 		case 0x03:
 			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_FULL;
 			break;
+		default: // case 0x00 and all other invalid stuff
+			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_LEFT;
+			break;
 		}
 	}
 }
 
-void WP1ContentListener::headerFooterGroup(uint8_t /* headerFooterDefinition */, WP1SubDocument *subDocument)
+void WP1ContentListener::headerFooterGroup(unsigned char /* headerFooterDefinition */, WP1SubDocument *subDocument)
 {
 	if (subDocument)
-		m_subDocuments.push_back(subDocument);			
-}	
+		m_subDocuments.push_back(subDocument);
+}
 
 void WP1ContentListener::setTabs(const std::vector<WPXTabStop> &tabStops)
 {
@@ -531,29 +534,30 @@ void WP1ContentListener::centerOn()
 	}
 }
 
-void WP1ContentListener::insertPicture(uint16_t width, uint16_t height, const WPXBinaryData &binaryData)
+void WP1ContentListener::insertPicture(unsigned short width, unsigned short height, const librevenge::RVNGBinaryData &binaryData)
 {
 	if (!isUndoOn())
 	{
 		if (!m_ps->m_isSpanOpened)
 			_openSpan();
 
-		WPXPropertyList propList;
+		librevenge::RVNGPropertyList propList;
 		propList.insert("svg:width", (double)((double)width/72.0));
 		propList.insert("svg:height", (double)((double)height/72.0));
 		propList.insert("text:anchor-type", "as-char");
 		m_documentInterface->openFrame(propList);
-		
+
 		propList.clear();
-		propList.insert("libwpd:mimetype", "image/pict");
-		m_documentInterface->insertBinaryObject(propList, binaryData);
-		
+		propList.insert("librevenge:mime-type", "image/pict");
+		propList.insert("office:binary-data", binaryData);
+		m_documentInterface->insertBinaryObject(propList);
+
 		m_documentInterface->closeFrame();
 	}
 }
 
-void WP1ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType /* subDocumentType */, 
-						WPXTableList /* tableList */, int /* nextTableIndice */)
+void WP1ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType /* subDocumentType */,
+                                            WPXTableList /* tableList */, unsigned /* nextTableIndice */)
 {
 	// save our old parsing state on our "stack"
 	WP1ContentParsingState *oldParseState = m_parseState;
@@ -593,3 +597,4 @@ void WP1ContentListener::_flushText()
 	_insertText(m_parseState->m_textBuffer);
 	m_parseState->m_textBuffer.clear();
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
