@@ -35,7 +35,7 @@ static unsigned pictureId = 0;
 #include <sstream>
 #endif
 
-WP1PictureGroup::WP1PictureGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group) :
+WP1PictureGroup::WP1PictureGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned char group) :
 	WP1VariableLengthGroup(group),
 	m_binaryData(),
 	m_width(0),
@@ -48,24 +48,24 @@ WP1PictureGroup::~WP1PictureGroup()
 {
 }
 
-void WP1PictureGroup::_readContents(WPXInputStream *input, WPXEncryption *encryption)
+void WP1PictureGroup::_readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption)
 {
 	m_binaryData.clear();
-	uint8_t tmpWhatNot = readU8(input, encryption);
+	unsigned char tmpWhatNot = readU8(input, encryption);
 	if (tmpWhatNot)
-		input->seek(1, WPX_SEEK_CUR);
+		input->seek(1, librevenge::RVNG_SEEK_CUR);
 	m_width = readU16(input, encryption, true);
 	m_height = readU16(input, encryption, true);
-	input->seek(6, WPX_SEEK_CUR);
-	uint32_t dataSize = readU16(input, encryption, true);
+	input->seek(6, librevenge::RVNG_SEEK_CUR);
+	unsigned dataSize = readU16(input, encryption, true);
 	WPD_DEBUG_MSG(("WP1PictureGroup: Offset = 0x%.4x, Width = %i, Height = %i, Data Size = 0x%.4x\n", (unsigned)input->tell(), m_width, m_height, dataSize));
 	if (dataSize + 13 > getSize())
 		return;
 	for (int i = 0; i < 512; i++)
 		m_binaryData.append((unsigned char)0);
-	m_binaryData.append((uint8_t)((dataSize + 512)>>8));
-	m_binaryData.append((uint8_t)(dataSize + 512));
-	for (unsigned long j = 2; j < dataSize && !input->atEOS(); j++ )
+	m_binaryData.append((unsigned char)((dataSize + 512)>>8));
+	m_binaryData.append((unsigned char)(dataSize + 512));
+	for (unsigned long j = 2; j < dataSize && !input->isEnd(); j++)
 		m_binaryData.append(readU8(input, encryption));
 #if DUMP_PICTURE
 	std::ostringstream filename;
@@ -73,8 +73,8 @@ void WP1PictureGroup::_readContents(WPXInputStream *input, WPXEncryption *encryp
 	FILE *f = fopen(filename.str().c_str(), "wb");
 	if (f)
 	{
-		WPXInputStream *tmpStream = const_cast<WPXInputStream *>(m_binaryData.getDataStream());
-		while (!tmpStream->atEOS())
+		librevenge::RVNGInputStream *tmpStream = m_binaryData.getDataStream();
+		while (!tmpStream->isEnd())
 			fprintf(f, "%c", readU8(tmpStream, 0));
 		fclose(f);
 	}
