@@ -27,7 +27,6 @@
 #define WP1PICTUREGROUP_H
 
 #include "WP1VariableLengthGroup.h"
-#include "WPXBinaryData.h"
 #include "libwpd_internal.h"
 
 class WP1SubDocument;
@@ -35,16 +34,16 @@ class WP1SubDocument;
 class WP1PictureGroup : public WP1VariableLengthGroup
 {
 public:
-	WP1PictureGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group);
+	WP1PictureGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned char group);
 	~WP1PictureGroup();
-	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
+	void _readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption);
 	void parse(WP1Listener *listener);
 
 private:
 	WP1PictureGroup(const WP1PictureGroup &);
 	WP1PictureGroup &operator=(const WP1PictureGroup &);
-	WPXBinaryData m_binaryData;
-	uint16_t m_width, m_height;
+	librevenge::RVNGBinaryData m_binaryData;
+	unsigned short m_width, m_height;
 };
 
 #endif /* WP1PICTUREGROUP_H */
