@@ -1,42 +1,43 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * For minor contributions see the git repository.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
- 
+
 #include "WP1StylesListener.h"
 #include "WP1FileStructure.h"
 #include "WPXFileStructure.h"
 #include "libwpd_internal.h"
 
-WP1StylesListener::WP1StylesListener(std::list<WPXPageSpan> &pageList, std::vector<WP1SubDocument *> &subDocuments) : 
+WP1StylesListener::WP1StylesListener(std::list<WPXPageSpan> &pageList, std::vector<WP1SubDocument *> &subDocuments) :
 	WP1Listener(),
 	WPXStylesListener(pageList),
 	m_currentPage(),
 	m_nextPage(),
 	m_subDocuments(subDocuments),
-	m_tempMarginLeft(1.0f),
-	m_tempMarginRight(1.0f),
+	m_tempMarginLeft(1.0),
+	m_tempMarginRight(1.0),
 	m_currentPageHasContent(false),
 	m_isSubDocument(false),
 	m_pageListHardPageMark(m_pageList.end())
@@ -44,24 +45,30 @@ WP1StylesListener::WP1StylesListener(std::list<WPXPageSpan> &pageList, std::vect
 }
 
 void WP1StylesListener::endDocument()
-{	
+{
 	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
 }
 
-void WP1StylesListener::insertBreak(const uint8_t breakType)
+void WP1StylesListener::endSubDocument()
+{
+	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
+}
+
+void WP1StylesListener::insertBreak(unsigned char breakType)
 {
 	if (m_isSubDocument)
 		return;
 
 	if (!isUndoOn())
-	{	
+	{
 		WPXTableList tableList;
-		switch (breakType) 
+		switch (breakType)
 		{
 		case WPX_PAGE_BREAK:
 		case WPX_SOFT_PAGE_BREAK:
+		{
 			if ((m_pageList.size() > 0) && (m_currentPage==m_pageList.back())
-				&& (m_pageListHardPageMark != m_pageList.end()))
+			        && (m_pageListHardPageMark != m_pageList.end()))
 			{
 				m_pageList.back().setPageSpan(m_pageList.back().getPageSpan() + 1);
 			}
@@ -70,29 +77,32 @@ void WP1StylesListener::insertBreak(const uint8_t breakType)
 				m_pageList.push_back(WPXPageSpan(m_currentPage));
 				if (m_pageListHardPageMark == m_pageList.end())
 				{
-					m_pageListHardPageMark--;
+					--m_pageListHardPageMark;
 				}
 			}
-			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0f, 0.0f);
+			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0, 0.0);
 			m_currentPage.setPageSpan(1);
 
-			for(std::vector<WPXHeaderFooter>::const_iterator HFiter = (m_nextPage.getHeaderFooterList()).begin();
-				HFiter != (m_nextPage.getHeaderFooterList()).end(); HFiter++)
+			for (std::vector<WPXHeaderFooter>::const_iterator HFiter = (m_nextPage.getHeaderFooterList()).begin();
+			        HFiter != (m_nextPage.getHeaderFooterList()).end(); ++HFiter)
 			{
-				if ((*HFiter).getOccurence() != NEVER)
+				if ((*HFiter).getOccurrence() != NEVER)
 				{
 					m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-						(*HFiter).getOccurence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
-					_handleSubDocument((*HFiter).getSubDocument(), true, (*HFiter).getTableList());
+					                              (*HFiter).getOccurrence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
+					_handleSubDocument((*HFiter).getSubDocument(), WPX_SUBDOCUMENT_HEADER_FOOTER, (*HFiter).getTableList());
 				}
 				else
 				{
 					m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-						(*HFiter).getOccurence(), 0, (*HFiter).getTableList());
-				}	
+					                              (*HFiter).getOccurrence(), 0, (*HFiter).getTableList());
+				}
 			}
 			m_nextPage = WPXPageSpan();
 			m_currentPageHasContent = false;
+		}
+		break;
+		default:
 			break;
 		}
 		if (breakType == WPX_PAGE_BREAK)
@@ -104,19 +114,19 @@ void WP1StylesListener::insertBreak(const uint8_t breakType)
 	}
 }
 
-void WP1StylesListener::marginReset(const uint16_t leftMargin, const uint16_t rightMargin)
+void WP1StylesListener::marginReset(unsigned short leftMargin, unsigned short rightMargin)
 {
-	if (!isUndoOn()) 
-	{		
+	if (!isUndoOn())
+	{
 		if (m_isSubDocument)
 			return; // do not collect L/R margin information in sub documents
 
 		std::list<WPXPageSpan>::iterator Iter;
-		float marginInch = 0.0f;
+		double marginInch = 0.0;
 
 		if (leftMargin)
 		{
-			marginInch = (float)((double)leftMargin / 72.0f);
+			marginInch = (double)((double)leftMargin / 72.0);
 			WPD_DEBUG_MSG(("Left Margin: %ipts = %.4finch\n", leftMargin, marginInch));
 			if (!m_currentPageHasContent && (m_pageListHardPageMark == m_pageList.end()))
 				m_currentPage.setMarginLeft(marginInch);
@@ -124,7 +134,7 @@ void WP1StylesListener::marginReset(const uint16_t leftMargin, const uint16_t ri
 			{
 				// Change the margin for the current page and for all pages in the list since the last Hard Break
 				m_currentPage.setMarginLeft(marginInch);
-				for (Iter = m_pageListHardPageMark; Iter != m_pageList.end(); Iter++)
+				for (Iter = m_pageListHardPageMark; Iter != m_pageList.end(); ++Iter)
 				{
 					(*Iter).setMarginLeft(marginInch);
 				}
@@ -134,7 +144,7 @@ void WP1StylesListener::marginReset(const uint16_t leftMargin, const uint16_t ri
 
 		if (rightMargin)
 		{
-			marginInch = (float)((double)rightMargin / 72.0f);
+			marginInch = (double)((double)rightMargin / 72.0);
 			WPD_DEBUG_MSG(("Right Margin: %ipts = %.4finch\n", rightMargin, marginInch));
 			if (!m_currentPageHasContent && (m_pageListHardPageMark == m_pageList.end()))
 				m_currentPage.setMarginRight(marginInch);
@@ -142,7 +152,7 @@ void WP1StylesListener::marginReset(const uint16_t leftMargin, const uint16_t ri
 			{
 				// Change the margin for the current page and for all pages in the list since the last Hard Break
 				m_currentPage.setMarginRight(marginInch);
-				for (Iter = m_pageListHardPageMark; Iter != m_pageList.end(); Iter++)
+				for (Iter = m_pageListHardPageMark; Iter != m_pageList.end(); ++Iter)
 				{
 					(*Iter).setMarginRight(marginInch);
 				}
@@ -152,27 +162,27 @@ void WP1StylesListener::marginReset(const uint16_t leftMargin, const uint16_t ri
 	}
 }
 
-void WP1StylesListener::topMarginSet(const uint16_t topMargin)
+void WP1StylesListener::topMarginSet(unsigned short topMargin)
 {
-	if (!isUndoOn()) 
+	if (!isUndoOn())
 	{
 		if (!topMargin) return;
-		float marginInch = (float)((double)topMargin / 72.0f);
+		double marginInch = (double)((double)topMargin / 72.0);
 		m_currentPage.setMarginTop(marginInch);
 	}
 }
 
-void WP1StylesListener::bottomMarginSet(const uint16_t bottomMargin)
+void WP1StylesListener::bottomMarginSet(unsigned short bottomMargin)
 {
-	if (!isUndoOn()) 
+	if (!isUndoOn())
 	{
 		if (!bottomMargin) return;
-		float marginInch = (float)((double)bottomMargin / 72.0f);
+		double marginInch = (double)((double)bottomMargin / 72.0);
 		m_currentPage.setMarginBottom(marginInch);
 	}
 }
 
-void WP1StylesListener::headerFooterGroup(const uint8_t headerFooterDefinition, WP1SubDocument *subDocument)
+void WP1StylesListener::headerFooterGroup(unsigned char headerFooterDefinition, WP1SubDocument *subDocument)
 {
 	if (subDocument)
 		m_subDocuments.push_back(subDocument);
@@ -181,44 +191,44 @@ void WP1StylesListener::headerFooterGroup(const uint8_t headerFooterDefinition,
 	{
 		bool tempCurrentPageHasContent = m_currentPageHasContent;
 
-		uint8_t headerFooterType = (headerFooterDefinition & 0x03);
+		unsigned char headerFooterType = (unsigned char)(headerFooterDefinition & 0x03);
 		WPXHeaderFooterType wpxType = ((headerFooterType <= WPX_HEADER_B) ? HEADER : FOOTER);
 
-		uint8_t occurenceBits = ((headerFooterDefinition & 0x1C) >> 2);
+		unsigned char occurrenceBits = (unsigned char)((headerFooterDefinition & 0x1C) >> 2);
 
-		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurenceBits: %i)\n", 
-			       headerFooterType, occurenceBits));
+		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurrenceBits: %i)\n",
+		               headerFooterType, occurrenceBits));
 
-		WPXHeaderFooterOccurence wpxOccurence;
+		WPXHeaderFooterOccurrence wpxOccurrence;
 
-		if (occurenceBits & WP1_HEADER_FOOTER_GROUP_ALL_BIT)
-			wpxOccurence = ALL;
-		else if (occurenceBits & WP1_HEADER_FOOTER_GROUP_EVEN_BIT)
-			wpxOccurence = EVEN;
-		else if (occurenceBits & WP1_HEADER_FOOTER_GROUP_ODD_BIT)
-			wpxOccurence = ODD;
+		if (occurrenceBits & WP1_HEADER_FOOTER_GROUP_ALL_BIT)
+			wpxOccurrence = ALL;
+		else if (occurrenceBits & WP1_HEADER_FOOTER_GROUP_EVEN_BIT)
+			wpxOccurrence = EVEN;
+		else if (occurrenceBits & WP1_HEADER_FOOTER_GROUP_ODD_BIT)
+			wpxOccurrence = ODD;
 		else
-			wpxOccurence = NEVER;
+			wpxOccurrence = NEVER;
 
 		WPXTableList tableList;
 
 		if ((wpxType == HEADER) && tempCurrentPageHasContent)
-			m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
+			m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, subDocument, tableList);
 		else /* FOOTER || !tempCurrentPageHasContent */
 		{
-			if (wpxOccurence != NEVER)
+			if (wpxOccurrence != NEVER)
 			{
-				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
-				_handleSubDocument(subDocument, true, tableList);
+				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, subDocument, tableList);
+				_handleSubDocument(subDocument, WPX_SUBDOCUMENT_HEADER_FOOTER, tableList);
 			}
 			else
-				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, 0, tableList);
+				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, 0, tableList);
 		}
 		m_currentPageHasContent = tempCurrentPageHasContent;
 	}
-}	
+}
 
-void WP1StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
+void WP1StylesListener::suppressPageCharacteristics(unsigned char suppressCode)
 {
 	if (!isUndoOn())
 	{
@@ -240,14 +250,14 @@ void WP1StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
 	}
 }
 
-void WP1StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter,
-						WPXTableList /* tableList */, int /* nextTableIndice */)
+void WP1StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
+                                           WPXTableList /* tableList */, int /* nextTableIndice */)
 {
-	if (!isUndoOn()) 
+	if (!isUndoOn())
 	{
 		bool oldIsSubDocument = m_isSubDocument;
 		m_isSubDocument = true;
-		if (isHeaderFooter) 
+		if (subDocumentType == WPX_SUBDOCUMENT_HEADER_FOOTER)
 		{
 			bool oldCurrentPageHasContent = m_currentPageHasContent;
 
@@ -264,3 +274,4 @@ void WP1StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, co
 		m_isSubDocument = oldIsSubDocument;
 	}
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
