@@ -1,19 +1,20 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,11 +28,11 @@
 #include "WP3FileStructure.h"
 #include "WP3Parser.h"
 
-WP3FootnoteEndnoteGroup::WP3FootnoteEndnoteGroup(WPXInputStream *input) :
+WP3FootnoteEndnoteGroup::WP3FootnoteEndnoteGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption) :
 	WP3VariableLengthGroup(),
 	m_subDocument(0)
 {
-	_read(input);
+	_read(input, encryption);
 }
 
 WP3FootnoteEndnoteGroup::~WP3FootnoteEndnoteGroup()
@@ -39,18 +40,18 @@ WP3FootnoteEndnoteGroup::~WP3FootnoteEndnoteGroup()
 	delete m_subDocument;
 }
 
-void WP3FootnoteEndnoteGroup::_readContents(WPXInputStream *input)
+void WP3FootnoteEndnoteGroup::_readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption)
 {
 	int tmpSizeOfNote = getSize() - 8;
-	input->seek(25, WPX_SEEK_CUR);
+	input->seek(25, librevenge::RVNG_SEEK_CUR);
 	tmpSizeOfNote -= 25;
-	unsigned tmpNumOfPages = readU16(input, true);
+	unsigned tmpNumOfPages = readU16(input, encryption, true);
 	tmpSizeOfNote -= 2;
-	input->seek(4*tmpNumOfPages, WPX_SEEK_CUR);
+	input->seek(4*tmpNumOfPages, librevenge::RVNG_SEEK_CUR);
 	tmpSizeOfNote -= 4*tmpNumOfPages;
-	unsigned tmpNumBreakTableEntries = readU16(input, true);
+	unsigned tmpNumBreakTableEntries = readU16(input, encryption, true);
 	tmpSizeOfNote -= 2;
-	input->seek(6*tmpNumBreakTableEntries, WPX_SEEK_CUR);
+	input->seek(6*tmpNumBreakTableEntries, librevenge::RVNG_SEEK_CUR);
 	tmpSizeOfNote -= 6*tmpNumBreakTableEntries;
 
 	// here we skipped all the useless junk and we are at the beginning of the
@@ -58,7 +59,7 @@ void WP3FootnoteEndnoteGroup::_readContents(WPXInputStream *input)
 	// subdocument
 
 	if (tmpSizeOfNote > 0)
-		m_subDocument = new WP3SubDocument(input, tmpSizeOfNote);
+		m_subDocument = new WP3SubDocument(input, encryption, (unsigned)tmpSizeOfNote);
 }
 
 void WP3FootnoteEndnoteGroup::parse(WP3Listener *listener)
@@ -76,3 +77,4 @@ void WP3FootnoteEndnoteGroup::parse(WP3Listener *listener)
 		break;
 	}
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
