@@ -1,22 +1,22 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2005-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
- * Copyright (C) 2007 Novell, Inc. (http://www.novell.com)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,7 +31,7 @@
 #include "libwpd_internal.h"
 #include "WP5SubDocument.h"
 
-_WP5ContentParsingState::_WP5ContentParsingState() :
+WP5ContentParsingState::WP5ContentParsingState() :
 	m_textBuffer(),
 	m_noteReference(),
 	m_tableList(),
@@ -39,11 +39,11 @@ _WP5ContentParsingState::_WP5ContentParsingState() :
 {
 }
 
-_WP5ContentParsingState::~_WP5ContentParsingState()
+WP5ContentParsingState::~WP5ContentParsingState()
 {
 }
 
-WP5ContentListener::WP5ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP5SubDocument*> &subDocuments, WPXDocumentInterface *documentInterface) :
+WP5ContentListener::WP5ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP5SubDocument *> &subDocuments, librevenge::RVNGTextInterface *documentInterface) :
 	WP5Listener(),
 	WPXContentListener(pageList, documentInterface),
 	m_parseState(new WP5ContentParsingState),
@@ -53,7 +53,7 @@ WP5ContentListener::WP5ContentListener(std::list<WPXPageSpan> &pageList, std::ve
 {
 }
 
-WP5ContentListener::~WP5ContentListener() 
+WP5ContentListener::~WP5ContentListener()
 {
 	delete m_parseState;
 }
@@ -63,15 +63,15 @@ WP5ContentListener::~WP5ContentListener()
  public 'HLListenerImpl' functions
 *****************************************/
 
-void WP5ContentListener::insertCharacter(uint32_t character)
+void WP5ContentListener::insertCharacter(unsigned character)
 {
-	uint32_t tmpCharacter = _mapNonUnicodeCharacter(character);
+	unsigned tmpCharacter = _mapNonUnicodeCharacter(character);
 	if (!m_ps->m_isSpanOpened)
 		_openSpan();
 	appendUCS4(m_parseState->m_textBuffer, tmpCharacter);
 }
 
-void WP5ContentListener::insertTab(uint8_t tabType, double tabPosition)
+void WP5ContentListener::insertTab(unsigned char tabType, double tabPosition)
 {
 	bool tmpHasTabPositionInformation = true;
 	if (tabPosition >= (double)((double)0xFFFE/(double)WPX_NUM_WPUS_PER_INCH) || tabPosition == 0.0)
@@ -115,8 +115,8 @@ void WP5ContentListener::insertTab(uint8_t tabType, double tabPosition)
 				if (!tmpHasTabPositionInformation)
 					m_ps->m_textIndentByTabs += 0.5f;
 				else
-					m_ps->m_textIndentByTabs = tabPosition - m_ps->m_paragraphMarginLeft - m_ps->m_pageMarginLeft 
-						- m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
+					m_ps->m_textIndentByTabs = tabPosition - m_ps->m_paragraphMarginLeft - m_ps->m_pageMarginLeft
+					                           - m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
 				break;
 
 			case WP5_TAB_GROUP_BACK_TAB: // converted as hanging indent
@@ -124,19 +124,19 @@ void WP5ContentListener::insertTab(uint8_t tabType, double tabPosition)
 					m_ps->m_textIndentByTabs -= 0.5f;
 				else
 					m_ps->m_textIndentByTabs = tabPosition - m_ps->m_paragraphMarginLeft - m_ps->m_pageMarginLeft
-						- m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
+					                           - m_ps->m_sectionMarginLeft - m_ps->m_textIndentByParagraphIndentChange;
 				break;
 
 			default:
 				break;
 			}
 			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
-				+ m_ps->m_textIndentByTabs;
+			                              + m_ps->m_textIndentByTabs;
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
 			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
-				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
-			
+			                               + m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+
 			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 
 		}
@@ -158,7 +158,7 @@ void WP5ContentListener::insertTab(uint8_t tabType, double tabPosition)
 			case WP5_TAB_GROUP_DECIMAL_TAB:
 				m_documentInterface->insertTab();
 				break;
-			
+
 			default:
 				break;
 			}
@@ -166,7 +166,7 @@ void WP5ContentListener::insertTab(uint8_t tabType, double tabPosition)
 	}
 }
 
-void WP5ContentListener::insertIndent(uint8_t indentType, double indentPosition)
+void WP5ContentListener::insertIndent(unsigned char indentType, double indentPosition)
 {
 	bool tmpHasIndentPositionInformation = true;
 	if (indentPosition >= (double)((double)0xFFFE/(double)WPX_NUM_WPUS_PER_INCH) || indentPosition == 0.0)
@@ -183,7 +183,7 @@ void WP5ContentListener::insertIndent(uint8_t indentType, double indentPosition)
 					m_ps->m_leftMarginByTabs += 0.5f;
 				else
 					m_ps->m_leftMarginByTabs = indentPosition - m_ps->m_pageMarginLeft - m_ps->m_sectionMarginRight
-						- m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
+					                           - m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
 				if (m_ps->m_paragraphTextIndent != 0.0)
 					m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
 				break;
@@ -193,22 +193,22 @@ void WP5ContentListener::insertIndent(uint8_t indentType, double indentPosition)
 					m_ps->m_leftMarginByTabs += 0.5f;
 				else
 					m_ps->m_leftMarginByTabs = indentPosition - m_ps->m_pageMarginLeft - m_ps->m_sectionMarginLeft
-						- m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
+					                           - m_ps->m_leftMarginByPageMarginChange - m_ps->m_leftMarginByParagraphMarginChange;
 				m_ps->m_rightMarginByTabs = m_ps->m_leftMarginByTabs;
 				if (m_ps->m_paragraphTextIndent != 0.0)
 					m_ps->m_textIndentByTabs -= m_ps->m_paragraphTextIndent;
-				break;	
-				
+				break;
+
 			default:
 				break;
 			}
 			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
-				+ m_ps->m_textIndentByTabs;
+			                              + m_ps->m_textIndentByTabs;
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-				+ m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange + m_ps->m_leftMarginByTabs;
 			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
-				+ m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
-			
+			                               + m_ps->m_rightMarginByParagraphMarginChange + m_ps->m_rightMarginByTabs;
+
 			m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 
 		}
@@ -237,7 +237,7 @@ void WP5ContentListener::insertEOL()
 	}
 }
 
-void WP5ContentListener::defineTable(uint8_t position, uint16_t leftOffset)
+void WP5ContentListener::defineTable(unsigned char position, unsigned short leftOffset)
 {
 	if (!isUndoOn())
 	{
@@ -272,8 +272,8 @@ void WP5ContentListener::defineTable(uint8_t position, uint16_t leftOffset)
 	}
 }
 
-void WP5ContentListener::addTableColumnDefinition(uint32_t width, uint32_t /* leftGutter */,
-						uint32_t /* rightGutter */, uint32_t attributes, uint8_t alignment)
+void WP5ContentListener::addTableColumnDefinition(unsigned width, unsigned /* leftGutter */,
+                                                  unsigned /* rightGutter */, unsigned attributes, unsigned char alignment)
 {
 	if (!isUndoOn())
 	{
@@ -285,11 +285,11 @@ void WP5ContentListener::addTableColumnDefinition(uint32_t width, uint32_t /* le
 
 		// add the new column definition to our table definition
 		m_ps->m_tableDefinition.m_columns.push_back(colDef);
-		
+
 		WPXColumnProperties colProp;
 		colProp.m_attributes = attributes;
 		colProp.m_alignment = alignment;
-		
+
 		m_ps->m_tableDefinition.m_columnsProperties.push_back(colProp);
 
 		// initialize the variable that tells us how many columns to skip
@@ -318,7 +318,7 @@ void WP5ContentListener::startTable()
 	}
 }
 
-void WP5ContentListener::insertRow(uint16_t rowHeight, bool isMinimumHeight, bool isHeaderRow)
+void WP5ContentListener::insertRow(unsigned short rowHeight, bool isMinimumHeight, bool isHeaderRow)
 {
 	if (!isUndoOn())
 	{
@@ -328,10 +328,10 @@ void WP5ContentListener::insertRow(uint16_t rowHeight, bool isMinimumHeight, boo
 	}
 }
 
-void WP5ContentListener::insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits,
-			const RGBSColor * cellFgColor, const RGBSColor * cellBgColor, 
-			const RGBSColor * cellBorderColor, WPXVerticalAlignment cellVerticalAlignment, 
-			bool useCellAttributes, uint32_t cellAttributes)
+void WP5ContentListener::insertCell(unsigned char colSpan, unsigned char rowSpan, unsigned char borderBits,
+                                    const RGBSColor *cellFgColor, const RGBSColor *cellBgColor,
+                                    const RGBSColor *cellBorderColor, WPXVerticalAlignment cellVerticalAlignment,
+                                    bool useCellAttributes, unsigned cellAttributes)
 {
 	if (!isUndoOn())
 	{
@@ -339,15 +339,15 @@ void WP5ContentListener::insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t bo
 			throw ParseException();
 		_flushText();
 		_openTableCell(colSpan, rowSpan, borderBits, cellFgColor, cellBgColor,
-					cellBorderColor, cellVerticalAlignment);
+		               cellBorderColor, cellVerticalAlignment);
 		m_ps->m_isCellWithoutParagraph = true;
 		if (m_ps->m_currentTableCol < 1)
 			return;
 		if (useCellAttributes)
 			m_ps->m_cellAttributeBits = cellAttributes;
 		else
-			m_ps->m_cellAttributeBits = m_ps->m_tableDefinition.m_columnsProperties[m_ps->m_currentTableCol-1].m_attributes;
-		justificationChange(m_ps->m_tableDefinition.m_columnsProperties[m_ps->m_currentTableCol-1].m_alignment);
+			m_ps->m_cellAttributeBits = m_ps->m_tableDefinition.m_columnsProperties[(size_t)(m_ps->m_currentTableCol-1)].m_attributes;
+		justificationChange(m_ps->m_tableDefinition.m_columnsProperties[(size_t)(m_ps->m_currentTableCol-1)].m_alignment);
 	}
 }
 
@@ -369,65 +369,67 @@ void WP5ContentListener::endTable()
  public 'parser' functions
 *****************************************/
 
-void WP5ContentListener::attributeChange(bool isOn, uint8_t attribute)
+void WP5ContentListener::attributeChange(bool isOn, unsigned char attribute)
 {
 	if (!isUndoOn())
 	{
 		_closeSpan();
 
-		uint32_t textAttributeBit = 0;
+		unsigned textAttributeBit = 0;
 
 		// FIXME: handle all the possible attribute bits
 		switch (attribute)
 		{
-			case WP5_ATTRIBUTE_EXTRA_LARGE:
-				textAttributeBit = WPX_EXTRA_LARGE_BIT;
-				break;
-			case WP5_ATTRIBUTE_VERY_LARGE:
-				textAttributeBit = WPX_VERY_LARGE_BIT;
-				break;
-			case WP5_ATTRIBUTE_LARGE:
-				textAttributeBit = WPX_LARGE_BIT;
-				break;
-			case WP5_ATTRIBUTE_SMALL_PRINT:
-				textAttributeBit = WPX_SMALL_PRINT_BIT;
-				break;
-			case WP5_ATTRIBUTE_FINE_PRINT:
-				textAttributeBit = WPX_FINE_PRINT_BIT;
-				break;		
-			case WP5_ATTRIBUTE_SUPERSCRIPT:
-				textAttributeBit = WPX_SUPERSCRIPT_BIT;
-				break;
-			case WP5_ATTRIBUTE_SUBSCRIPT:
-				textAttributeBit = WPX_SUBSCRIPT_BIT;
-				break;
-			case WP5_ATTRIBUTE_OUTLINE:
-				textAttributeBit = WPX_OUTLINE_BIT;
-				break;
-			case WP5_ATTRIBUTE_ITALICS:
-				textAttributeBit = WPX_ITALICS_BIT;
-				break;
-			case WP5_ATTRIBUTE_SHADOW:
-				textAttributeBit = WPX_SHADOW_BIT;
-				break;
-			case WP5_ATTRIBUTE_REDLINE:
-				textAttributeBit = WPX_REDLINE_BIT;
-				break;
-			case WP5_ATTRIBUTE_DOUBLE_UNDERLINE:
-				textAttributeBit = WPX_DOUBLE_UNDERLINE_BIT;
-				break;
-			case WP5_ATTRIBUTE_BOLD:
-				textAttributeBit = WPX_BOLD_BIT;
-				break;
-			case WP5_ATTRIBUTE_STRIKE_OUT:
-				textAttributeBit = WPX_STRIKEOUT_BIT;
-				break;
-			case WP5_ATTRIBUTE_UNDERLINE:
-				textAttributeBit = WPX_UNDERLINE_BIT;
-				break;
-			case WP5_ATTRIBUTE_SMALL_CAPS:
-				textAttributeBit = WPX_SMALL_CAPS_BIT;
-				break;
+		case WP5_ATTRIBUTE_EXTRA_LARGE:
+			textAttributeBit = WPX_EXTRA_LARGE_BIT;
+			break;
+		case WP5_ATTRIBUTE_VERY_LARGE:
+			textAttributeBit = WPX_VERY_LARGE_BIT;
+			break;
+		case WP5_ATTRIBUTE_LARGE:
+			textAttributeBit = WPX_LARGE_BIT;
+			break;
+		case WP5_ATTRIBUTE_SMALL_PRINT:
+			textAttributeBit = WPX_SMALL_PRINT_BIT;
+			break;
+		case WP5_ATTRIBUTE_FINE_PRINT:
+			textAttributeBit = WPX_FINE_PRINT_BIT;
+			break;
+		case WP5_ATTRIBUTE_SUPERSCRIPT:
+			textAttributeBit = WPX_SUPERSCRIPT_BIT;
+			break;
+		case WP5_ATTRIBUTE_SUBSCRIPT:
+			textAttributeBit = WPX_SUBSCRIPT_BIT;
+			break;
+		case WP5_ATTRIBUTE_OUTLINE:
+			textAttributeBit = WPX_OUTLINE_BIT;
+			break;
+		case WP5_ATTRIBUTE_ITALICS:
+			textAttributeBit = WPX_ITALICS_BIT;
+			break;
+		case WP5_ATTRIBUTE_SHADOW:
+			textAttributeBit = WPX_SHADOW_BIT;
+			break;
+		case WP5_ATTRIBUTE_REDLINE:
+			textAttributeBit = WPX_REDLINE_BIT;
+			break;
+		case WP5_ATTRIBUTE_DOUBLE_UNDERLINE:
+			textAttributeBit = WPX_DOUBLE_UNDERLINE_BIT;
+			break;
+		case WP5_ATTRIBUTE_BOLD:
+			textAttributeBit = WPX_BOLD_BIT;
+			break;
+		case WP5_ATTRIBUTE_STRIKE_OUT:
+			textAttributeBit = WPX_STRIKEOUT_BIT;
+			break;
+		case WP5_ATTRIBUTE_UNDERLINE:
+			textAttributeBit = WPX_UNDERLINE_BIT;
+			break;
+		case WP5_ATTRIBUTE_SMALL_CAPS:
+			textAttributeBit = WPX_SMALL_CAPS_BIT;
+			break;
+		default:
+			break;
 		}
 
 		if (isOn)
@@ -437,13 +439,13 @@ void WP5ContentListener::attributeChange(bool isOn, uint8_t attribute)
 	}
 }
 
-void WP5ContentListener::marginChange(uint8_t side, uint16_t margin)
+void WP5ContentListener::marginChange(unsigned char side, unsigned short margin)
 {
 	if (!isUndoOn())
 	{
 		double marginInch = (double)((double)margin/ (double)WPX_NUM_WPUS_PER_INCH);
 
-		switch(side)
+		switch (side)
 		{
 		case WPX_LEFT:
 			if (m_ps->m_numColumns > 1)
@@ -457,8 +459,8 @@ void WP5ContentListener::marginChange(uint8_t side, uint16_t margin)
 				m_ps->m_sectionMarginLeft = 0.0;
 			}
 			m_ps->m_paragraphMarginLeft = m_ps->m_leftMarginByPageMarginChange
-						+ m_ps->m_leftMarginByParagraphMarginChange
-						+ m_ps->m_leftMarginByTabs;
+			                              + m_ps->m_leftMarginByParagraphMarginChange
+			                              + m_ps->m_leftMarginByTabs;
 			break;
 		case WPX_RIGHT:
 			if (m_ps->m_numColumns > 1)
@@ -472,15 +474,17 @@ void WP5ContentListener::marginChange(uint8_t side, uint16_t margin)
 				m_ps->m_sectionMarginRight = 0.0;
 			}
 			m_ps->m_paragraphMarginRight = m_ps->m_rightMarginByPageMarginChange
-						+ m_ps->m_rightMarginByParagraphMarginChange
-						+ m_ps->m_rightMarginByTabs;
+			                               + m_ps->m_rightMarginByParagraphMarginChange
+			                               + m_ps->m_rightMarginByTabs;
+			break;
+		default:
 			break;
 		}
 		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 	}
 }
 
-void WP5ContentListener::characterColorChange(uint8_t red, uint8_t green, uint8_t blue)
+void WP5ContentListener::characterColorChange(unsigned char red, unsigned char green, unsigned char blue)
 {
 	if (!isUndoOn())
 	{
@@ -488,10 +492,10 @@ void WP5ContentListener::characterColorChange(uint8_t red, uint8_t green, uint8_
 		m_ps->m_fontColor->m_r = red;
 		m_ps->m_fontColor->m_g = green;
 		m_ps->m_fontColor->m_b = blue;
- 	}
+	}
 }
 
-void WP5ContentListener::setFont(const WPXString &fontName, double fontSize)
+void WP5ContentListener::setFont(const librevenge::RVNGString &fontName, double fontSize)
 {
 	if (!isUndoOn())
 	{
@@ -501,7 +505,7 @@ void WP5ContentListener::setFont(const WPXString &fontName, double fontSize)
 	}
 }
 
-void WP5ContentListener::setTabs(const std::vector<WPXTabStop> &tabStops, uint16_t tabOffset)
+void WP5ContentListener::setTabs(const std::vector<WPXTabStop> &tabStops, unsigned short tabOffset)
 {
 	if (!isUndoOn())
 	{
@@ -511,7 +515,7 @@ void WP5ContentListener::setTabs(const std::vector<WPXTabStop> &tabStops, uint16
 }
 
 
-void WP5ContentListener::insertNoteReference(const WPXString &noteReference)
+void WP5ContentListener::insertNoteReference(const librevenge::RVNGString &noteReference)
 {
 	if (!isUndoOn() && !m_ps->m_isNote)
 	{
@@ -534,9 +538,9 @@ void WP5ContentListener::insertNote(WPXNoteType noteType, const WP5SubDocument *
 		WPXNumberingType numberingType = _extractWPXNumberingTypeFromBuf(m_parseState->m_noteReference, ARABIC);
 		int number = _extractDisplayReferenceNumberFromBuf(m_parseState->m_noteReference, numberingType);
 		m_parseState->m_noteReference.clear();
-		
-		WPXPropertyList propList;
-		propList.insert("libwpd:number", number);
+
+		librevenge::RVNGPropertyList propList;
+		propList.insert("librevenge:number", number);
 
 		if (noteType == FOOTNOTE)
 			m_documentInterface->openFootnote(propList);
@@ -553,8 +557,8 @@ void WP5ContentListener::insertNote(WPXNoteType noteType, const WP5SubDocument *
 	}
 }
 
-void WP5ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, 
-	WPXTableList /* tableList */, int /* nextTableIndice */)
+void WP5ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
+                                            WPXTableList /* tableList */, unsigned /* nextTableIndice */)
 {
 	// save our old parsing state on our "stack"
 	WP5ContentParsingState *oldParseState = m_parseState;
@@ -590,80 +594,80 @@ void WP5ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, W
 	m_parseState = oldParseState;
 }
 
-void WP5ContentListener::headerFooterGroup(uint8_t /* headerFooterType */, uint8_t /* occurenceBits */,
-						WP5SubDocument *subDocument)
+void WP5ContentListener::headerFooterGroup(unsigned char /* headerFooterType */, unsigned char /* occurrenceBits */,
+                                           WP5SubDocument *subDocument)
 {
 	if (subDocument)
 		m_subDocuments.push_back(subDocument);
-}	
+}
 
-void WP5ContentListener::setDefaultFont(const WPXString &fontName, double fontSize)
+void WP5ContentListener::setDefaultFont(const librevenge::RVNGString &fontName, double fontSize)
 {
 	m_defaultFontName = fontName;
 	m_defaultFontSize = fontSize;
 }
 
-void WP5ContentListener::boxOn(uint8_t positionAndType, uint8_t alignment, uint16_t width, uint16_t height, uint16_t x, uint16_t y)
+void WP5ContentListener::boxOn(unsigned char positionAndType, unsigned char alignment, unsigned short width, unsigned short height, unsigned short x, unsigned short y)
 {
-/*
-Paragraph:
-	- Vertical position:
-		+ offset from top of paragraph
-	- Horizontal position:
-		+ Left
-		+ Right
-		+ Centre
-		+ Full
+	/*
+	Paragraph:
+		- Vertical position:
+			+ offset from top of paragraph
+		- Horizontal position:
+			+ Left
+			+ Right
+			+ Centre
+			+ Full
 
-Page:
-	- Vertical position:
-		+ Full Page
-		+ Top
-		+ Centre
-		+ Bottom
-		+ Set Position
-			* Offset from the top of page
-	- Horizontal position
-		+ Margins
-			* Left
-			* Right
-			* Centre
-			* Full
-		+ Columns (Which column)
-			* Left
-			* Right
-			* Centre
-			* Full
-		+ Set Position
-			* Offset from left of page
+	Page:
+		- Vertical position:
+			+ Full Page
+			+ Top
+			+ Centre
+			+ Bottom
+			+ Set Position
+				* Offset from the top of page
+		- Horizontal position
+			+ Margins
+				* Left
+				* Right
+				* Centre
+				* Full
+			+ Columns (Which column)
+				* Left
+				* Right
+				* Centre
+				* Full
+			+ Set Position
+				* Offset from left of page
 
-Character:
-	- Vertical position:
-		+ Top
-		+ Centre
-		+ Bottom
-		+ Baseline
-	- Horizontal Position:
-		+ N/A
-*/
+	Character:
+		- Vertical position:
+			+ Top
+			+ Centre
+			+ Bottom
+			+ Baseline
+		- Horizontal Position:
+			+ N/A
+	*/
 
 	if (isUndoOn() || (m_ps->m_isTableOpened && !m_ps->m_isTableCellOpened))
 		return;
-		 
+
 	if (!m_ps->m_isSpanOpened)
 		_openSpan();
 	else
 		_flushText();
 
-	WPXPropertyList propList;
+	librevenge::RVNGPropertyList propList;
 
 	propList.insert("svg:height", (double)((double)height/(double)WPX_NUM_WPUS_PER_INCH));
 	propList.insert("svg:width", (double)((double)width/(double)WPX_NUM_WPUS_PER_INCH));
 
-	if ( alignment & 0x80 )
-		propList.insert( "style:wrap", "dynamic" );
+	if (alignment & 0x80)
+		propList.insert("style:wrap", "dynamic");
 	else
-		propList.insert( "style:wrap", "none" );
+		propList.insert("style:wrap", "none");
 
 
 	switch (positionAndType & 0x03)
@@ -680,115 +684,115 @@ Character:
 	default:
 		break;
 	}
-	
+
 	propList.insert("style:vertical-rel", "page-content");
-	switch ( (positionAndType &  0x1c) >> 2 )
+	switch ((positionAndType &  0x1c) >> 2)
 	{
 	case 0x00:
-		propList.insert("svg:height", (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom ) );
-		propList.insert("style:vertical-rel", "page-content" );
-		propList.insert("style:vertical-pos", "middle" );
+		propList.insert("svg:height", (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom));
+		propList.insert("style:vertical-rel", "page-content");
+		propList.insert("style:vertical-pos", "middle");
 		break;
 	case 0x01:
-		if ( y == 0.0)
-			propList.insert("style:vertical-pos", "top" );
+		if (y == 0.0)
+			propList.insert("style:vertical-pos", "top");
 		else
 		{
-			propList.insert("style:vertical-pos", "from-top" );
+			propList.insert("style:vertical-pos", "from-top");
 			double newPosition = (double)((double)y/(double)WPX_NUM_WPUS_PER_INCH);
 			if (newPosition > (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH) )
+			                           - (double)height/(double)WPX_NUM_WPUS_PER_INCH))
 			{
 				newPosition = (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH);
+				                       - (double)height/(double)WPX_NUM_WPUS_PER_INCH);
 			}
 			propList.insert("svg:y", newPosition);
 		}
 		break;
 	case 0x02:
 		if (y == 0.0)
-			propList.insert("style:vertical-pos", "middle" );
+			propList.insert("style:vertical-pos", "middle");
 		else
 		{
-			propList.insert("style:vertical-pos", "from-top" );
+			propList.insert("style:vertical-pos", "from-top");
 			double newPosition = (double)((m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH)/2.0);
+			                               - (double)height/(double)WPX_NUM_WPUS_PER_INCH)/2.0);
 			if (newPosition > (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH) )
+			                           - (double)height/(double)WPX_NUM_WPUS_PER_INCH))
 			{
 				newPosition = (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-					- (double)height/(double)WPX_NUM_WPUS_PER_INCH);
+				                       - (double)height/(double)WPX_NUM_WPUS_PER_INCH);
 			}
 			propList.insert("svg:y", newPosition);
 		}
 		break;
 	case 0x03:
 		if (y == 0.0)
-			propList.insert("style:vertical-pos", "bottom" );
+			propList.insert("style:vertical-pos", "bottom");
 		else
 		{
-			propList.insert("style:vertical-pos", "from-top" );
+			propList.insert("style:vertical-pos", "from-top");
 			double newPosition = (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH + (double)y/(double)WPX_NUM_WPUS_PER_INCH);
+			                              - (double)height/(double)WPX_NUM_WPUS_PER_INCH + (double)y/(double)WPX_NUM_WPUS_PER_INCH);
 			if (newPosition > (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-				- (double)height/(double)WPX_NUM_WPUS_PER_INCH) )
+			                           - (double)height/(double)WPX_NUM_WPUS_PER_INCH))
 			{
 				newPosition = (double)(m_ps->m_pageFormLength - m_ps->m_pageMarginTop - m_ps->m_pageMarginBottom
-					- (double)height/(double)WPX_NUM_WPUS_PER_INCH);
+				                       - (double)height/(double)WPX_NUM_WPUS_PER_INCH);
 			}
 			propList.insert("svg:y", newPosition);
 		}
 		break;
 	case 0x04:
-		propList.insert("style:vertical-rel", "page" );
-		propList.insert("style:vertical-pos", "from-top" );
+		propList.insert("style:vertical-rel", "page");
+		propList.insert("style:vertical-pos", "from-top");
 		propList.insert("svg:y", (double)((double)y/(double)WPX_NUM_WPUS_PER_INCH));
 		break;
 	default:
 		break;
 	}
-	
-	propList.insert("style:horizontal-rel", "page-content" );
-	switch ( alignment & 0x03 )
+
+	propList.insert("style:horizontal-rel", "page-content");
+	switch (alignment & 0x03)
 	{
 	case 0x00:
-		if ( x == 0.0 )
-			propList.insert( "style:horizontal-pos", "left");
+		if (x == 0.0)
+			propList.insert("style:horizontal-pos", "left");
 		else
 		{
-			propList.insert( "style:horizontal-pos", "from-left");
-			propList.insert( "svg:x", (double)((double)x/(double)WPX_NUM_WPUS_PER_INCH));
+			propList.insert("style:horizontal-pos", "from-left");
+			propList.insert("svg:x", (double)((double)x/(double)WPX_NUM_WPUS_PER_INCH));
 		}
 		break;
 	case 0x01:
-		if ( x == 0.0 )
-			propList.insert( "style:horizontal-pos", "right");
+		if (x == 0.0)
+			propList.insert("style:horizontal-pos", "right");
 		else
 		{
-			propList.insert( "style:horizontal-pos", "from-left");
-			propList.insert( "svg:x", (double)(m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight
-				- (double)width/(double)WPX_NUM_WPUS_PER_INCH + (double)x/(double)WPX_NUM_WPUS_PER_INCH));
+			propList.insert("style:horizontal-pos", "from-left");
+			propList.insert("svg:x", (double)(m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight
+			                                  - (double)width/(double)WPX_NUM_WPUS_PER_INCH + (double)x/(double)WPX_NUM_WPUS_PER_INCH));
 		}
 		break;
 	case 0x02:
-		if ( x == 0.0 )
-			propList.insert( "style:horizontal-pos", "center" );
+		if (x == 0.0)
+			propList.insert("style:horizontal-pos", "center");
 		else
 		{
-			propList.insert( "style:horizontal-pos", "from-left");
-			propList.insert( "svg:x", (double)((m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight
-				- (double)width/(double)WPX_NUM_WPUS_PER_INCH)/2.0 + (double)x/(double)WPX_NUM_WPUS_PER_INCH));
+			propList.insert("style:horizontal-pos", "from-left");
+			propList.insert("svg:x", (double)((m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight
+			                                   - (double)width/(double)WPX_NUM_WPUS_PER_INCH)/2.0 + (double)x/(double)WPX_NUM_WPUS_PER_INCH));
 		}
 		break;
 	case 0x03:
-		propList.insert("svg:width", (double)(m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight ) );
-		propList.insert("style:horizontal-rel", "page-content" );
-		propList.insert("style:horizontal-pos", "center" );
+		propList.insert("svg:width", (double)(m_ps->m_pageFormWidth - m_ps->m_pageMarginLeft - m_ps->m_pageMarginRight));
+		propList.insert("style:horizontal-rel", "page-content");
+		propList.insert("style:horizontal-pos", "center");
 		break;
 	default:
 		break;
 	}
-	
+
 	m_documentInterface->openFrame(propList);
 	m_parseState->m_isFrameOpened = true;
 }
@@ -802,16 +806,17 @@ void WP5ContentListener::boxOff()
 	}
 }
 
-void WP5ContentListener::insertGraphicsData(const WPXBinaryData *data)
+void WP5ContentListener::insertGraphicsData(const librevenge::RVNGBinaryData *data)
 {
 	if (isUndoOn() || !m_parseState->m_isFrameOpened)
 		return;
 
-	if (data) 
+	if (data)
 	{
-		WPXPropertyList propList;
-		propList.insert("libwpd:mimetype", "image/x-wpg");
-		m_documentInterface->insertBinaryObject(propList, *data);
+		librevenge::RVNGPropertyList propList;
+		propList.insert("librevenge:mime-type", "image/x-wpg");
+		propList.insert("office:binary-data", *data);
+		m_documentInterface->insertBinaryObject(propList);
 	}
 }
 
@@ -826,3 +831,4 @@ void WP5ContentListener::_flushText()
 	m_parseState->m_textBuffer.clear();
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
