@@ -58,7 +58,7 @@ void WP5StylesListener::endSubDocument()
 	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
 }
 
-void WP5StylesListener::insertBreak(uint8_t breakType)
+void WP5StylesListener::insertBreak(unsigned char breakType)
 {
 	if (m_isSubDocument)
 		return;
@@ -70,6 +70,7 @@ void WP5StylesListener::insertBreak(uint8_t breakType)
 	{
 	case WPX_PAGE_BREAK:
 	case WPX_SOFT_PAGE_BREAK:
+	{
 		if ((m_pageList.size() > 0) && (m_currentPage==m_pageList.back())
 		        && (m_pageListHardPageMark != m_pageList.end()))
 		{
@@ -84,22 +85,23 @@ void WP5StylesListener::insertBreak(uint8_t breakType)
 		m_currentPage = WPXPageSpan(m_pageList.back(), 0.0, 0.0);
 		m_currentPage.setPageSpan(1);
 
-		for(std::vector<WPXHeaderFooter>::const_iterator HFiter = (m_nextPage.getHeaderFooterList()).begin();
+		for (std::vector<WPXHeaderFooter>::const_iterator HFiter = (m_nextPage.getHeaderFooterList()).begin();
 		        HFiter != (m_nextPage.getHeaderFooterList()).end(); ++HFiter)
 		{
-			if ((*HFiter).getOccurence() != NEVER)
+			if ((*HFiter).getOccurrence() != NEVER)
 			{
 				m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-				                              (*HFiter).getOccurence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
+				                              (*HFiter).getOccurrence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
 				_handleSubDocument((*HFiter).getSubDocument(), WPX_SUBDOCUMENT_HEADER_FOOTER, (*HFiter).getTableList());
 			}
 			else
 				m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-				                              (*HFiter).getOccurence(), 0, (*HFiter).getTableList());
+				                              (*HFiter).getOccurrence(), 0, (*HFiter).getTableList());
 		}
 		m_nextPage = WPXPageSpan();
 		m_currentPageHasContent = false;
-		break;
+	}
+	break;
 	default:
 		break;
 	}
@@ -112,12 +114,12 @@ void WP5StylesListener::insertBreak(uint8_t breakType)
 	//}
 }
 
-void WP5StylesListener::pageMarginChange(uint8_t side, uint16_t margin)
+void WP5StylesListener::pageMarginChange(unsigned char side, unsigned short margin)
 {
 	//if (!isUndoOn())
 	//{
 	double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
-	switch(side)
+	switch (side)
 	{
 	case WPX_TOP:
 		m_currentPage.setMarginTop(marginInch);
@@ -131,7 +133,7 @@ void WP5StylesListener::pageMarginChange(uint8_t side, uint16_t margin)
 	//}
 }
 
-void WP5StylesListener::pageFormChange(uint16_t length, uint16_t width, WPXFormOrientation orientation)
+void WP5StylesListener::pageFormChange(unsigned short length, unsigned short width, WPXFormOrientation orientation)
 {
 	//if (!isUndoOn())
 	//{
@@ -147,7 +149,7 @@ void WP5StylesListener::pageFormChange(uint16_t length, uint16_t width, WPXFormO
 }
 
 
-void WP5StylesListener::marginChange(uint8_t side, uint16_t margin)
+void WP5StylesListener::marginChange(unsigned char side, unsigned short margin)
 {
 	if (!isUndoOn())
 	{
@@ -156,7 +158,7 @@ void WP5StylesListener::marginChange(uint8_t side, uint16_t margin)
 
 		std::list<WPXPageSpan>::iterator Iter;
 		double marginInch = (double)((double)margin / (double)WPX_NUM_WPUS_PER_INCH);
-		switch(side)
+		switch (side)
 		{
 		case WPX_LEFT:
 			if (!m_currentPageHasContent && (m_pageListHardPageMark == m_pageList.end()))
@@ -194,47 +196,47 @@ void WP5StylesListener::marginChange(uint8_t side, uint16_t margin)
 
 }
 
-void WP5StylesListener::headerFooterGroup(uint8_t headerFooterType, uint8_t occurenceBits, WP5SubDocument *subDocument)
+void WP5StylesListener::headerFooterGroup(unsigned char headerFooterType, unsigned char occurrenceBits, WP5SubDocument *subDocument)
 {
 	if (subDocument)
 		m_subDocuments.push_back(subDocument);
 
 	if (!isUndoOn())
 	{
-		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurenceBits: %i)\n",
-		               headerFooterType, occurenceBits));
+		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurrenceBits: %i)\n",
+		               headerFooterType, occurrenceBits));
 		bool tempCurrentPageHasContent = m_currentPageHasContent;
 		if (headerFooterType <= WP5_HEADER_FOOTER_GROUP_FOOTER_B)
 		{
 			WPXHeaderFooterType wpxType = ((headerFooterType <= WP5_HEADER_FOOTER_GROUP_HEADER_B) ? HEADER : FOOTER);
 
-			WPXHeaderFooterOccurence wpxOccurence;
-			if (occurenceBits & WP5_HEADER_FOOTER_GROUP_ALL_BIT)
-				wpxOccurence = ALL;
-			else if (occurenceBits & WP5_HEADER_FOOTER_GROUP_EVEN_BIT)
-				wpxOccurence = EVEN;
-			else if (occurenceBits & WP5_HEADER_FOOTER_GROUP_ODD_BIT)
-				wpxOccurence = ODD;
+			WPXHeaderFooterOccurrence wpxOccurrence;
+			if (occurrenceBits & WP5_HEADER_FOOTER_GROUP_ALL_BIT)
+				wpxOccurrence = ALL;
+			else if (occurrenceBits & WP5_HEADER_FOOTER_GROUP_EVEN_BIT)
+				wpxOccurrence = EVEN;
+			else if (occurrenceBits & WP5_HEADER_FOOTER_GROUP_ODD_BIT)
+				wpxOccurrence = ODD;
 			else
-				wpxOccurence = NEVER;
+				wpxOccurrence = NEVER;
 			WPXTableList tableList;
 
 			if ((wpxType == HEADER) && tempCurrentPageHasContent)
 			{
-				if (wpxOccurence != NEVER)
-					m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
+				if (wpxOccurrence != NEVER)
+					m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, subDocument, tableList);
 				else
-					m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, 0, tableList);
+					m_nextPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, 0, tableList);
 			}
 			else /* FOOTER || !tempCurrentPageHasContent */
 			{
-				if (wpxOccurence != NEVER)
+				if (wpxOccurrence != NEVER)
 				{
-					m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
+					m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, subDocument, tableList);
 					_handleSubDocument(subDocument, WPX_SUBDOCUMENT_HEADER_FOOTER, tableList);
 				}
 				else
-					m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, 0, tableList);
+					m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurrence, 0, tableList);
 			}
 		}
 		m_currentPageHasContent = tempCurrentPageHasContent;
@@ -242,7 +244,7 @@ void WP5StylesListener::headerFooterGroup(uint8_t headerFooterType, uint8_t occu
 }
 
 
-void WP5StylesListener::suppressPageCharacteristics(uint8_t suppressCode)
+void WP5StylesListener::suppressPageCharacteristics(unsigned char suppressCode)
 {
 	if (!isUndoOn())
 	{
@@ -268,7 +270,7 @@ void WP5StylesListener::startTable()
 	}
 }
 
-void WP5StylesListener::insertRow(uint16_t /* rowHeight */, bool /* isMinimumHeight */, bool /* isHeaderRow */)
+void WP5StylesListener::insertRow(unsigned short /* rowHeight */, bool /* isMinimumHeight */, bool /* isHeaderRow */)
 {
 	if (!isUndoOn())
 	{
@@ -279,10 +281,10 @@ void WP5StylesListener::insertRow(uint16_t /* rowHeight */, bool /* isMinimumHei
 	}
 }
 
-void WP5StylesListener::insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits,
+void WP5StylesListener::insertCell(unsigned char colSpan, unsigned char rowSpan, unsigned char borderBits,
                                    const RGBSColor * /* cellFgColor */, const RGBSColor * /* cellBgColor */,
                                    const RGBSColor * /* cellBorderColor */, WPXVerticalAlignment /* cellVerticalAlignment */,
-                                   bool /* useCellAttributes */, uint32_t /* cellAttributes */)
+                                   bool /* useCellAttributes */, unsigned /* cellAttributes */)
 {
 	if (!isUndoOn())
 	{
@@ -294,7 +296,7 @@ void WP5StylesListener::insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t bor
 }
 
 void WP5StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
-        WPXTableList tableList, int /* nextTableIndice */)
+                                           WPXTableList tableList, int /* nextTableIndice */)
 {
 	// We don't want to actual insert anything in the case of a sub-document, but we
 	// do want to capture whatever table-related information is within it..
