@@ -30,7 +30,7 @@
 #include "libwpd_internal.h"
 
 // size of the fixed length functiongroups 0xF0 to 0xFF
-extern uint8_t WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
+extern unsigned char WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 
 /* standard sizes */
 #define WP6_NUM_LIST_LEVELS 8
@@ -49,6 +49,7 @@ extern uint8_t WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_INDEX_HEADER_ELEMENT_CHILD_PACKET_BIT 1
 
 #define WP6_INDEX_HEADER_DOCUMENT_SETTINGS_DESCRIPTOR_POOL 0x02
+#define WP6_INDEX_HEADER_HYPERLINK 0x07
 #define WP6_INDEX_HEADER_GENERAL_WORDPERFECT_TEXT 0x08
 #define WP6_INDEX_HEADER_NEXT_TOTAL_PAGE_COUNT_DESCRIPTOR_POOL 0x10
 #define WP6_INDEX_HEADER_COMMENT_ANNOTATION 0x1B
