@@ -24,6 +24,8 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 
+#include <algorithm>
+
 #include <librevenge/librevenge.h>
 #include "WPXHeader.h"
 #include "WPXParser.h"
@@ -64,6 +66,9 @@ WPDAPI WPDConfidence WPDocument::isFileFormatSupported(librevenge::RVNGInputStre
 {
 	WPD_DEBUG_MSG(("WPDocument::isFileFormatSupported()\n"));
 
+	if (!input)
+		return WPD_CONFIDENCE_NONE;
+
 	// by-pass the OLE stream (if it exists) and returns the (sub) stream with the
 	// WordPerfect document.
 	librevenge::RVNGInputStream *document = 0;
@@ -132,7 +137,7 @@ WPDAPI WPDConfidence WPDocument::isFileFormatSupported(librevenge::RVNGInputStre
 		else
 			confidence = WP1Heuristics::isWP1FileFormat(input, 0);
 		if (confidence != WPD_CONFIDENCE_EXCELLENT && confidence != WPD_CONFIDENCE_SUPPORTED_ENCRYPTION)
-			confidence = LIBWPD_MAX(confidence, WP42Heuristics::isWP42FileFormat(input, 0));
+			confidence = (std::max)(confidence, WP42Heuristics::isWP42FileFormat(input, 0));
 
 
 		// dispose of the reference to the ole input stream, if we allocated one
@@ -218,7 +223,7 @@ WPDAPI WPDPasswordMatch WPDocument::verifyPassword(librevenge::RVNGInputStream *
 		else
 			passwordMatch = WP1Heuristics::verifyPassword(input, password);
 		if (passwordMatch == WPD_PASSWORD_MATCH_NONE)
-			passwordMatch = LIBWPD_MAX(passwordMatch, WP42Heuristics::verifyPassword(input, password));
+			passwordMatch = (std::max)(passwordMatch, WP42Heuristics::verifyPassword(input, password));
 
 
 		// dispose of the reference to the ole input stream, if we allocated one
@@ -418,6 +423,9 @@ WPDAPI WPDResult WPDocument::parse(librevenge::RVNGInputStream *input, libreveng
 
 WPDAPI WPDResult WPDocument::parseSubDocument(librevenge::RVNGInputStream *input, librevenge::RVNGTextInterface *textInterface, WPDFileFormat fileFormat)
 {
+	if (!input)
+		return WPD_FILE_ACCESS_ERROR;
+
 	WPXParser *parser = 0;
 
 	WPDResult error = WPD_OK;
