@@ -26,13 +26,12 @@
 #include "WPXContentListener.h"
 #include "WPXPageSpan.h"
 #include "libwpd_internal.h"
-#include "WPXProperty.h"
 #include <limits>
 
-_WPXContentParsingState::_WPXContentParsingState() :
+WPXContentParsingState::WPXContentParsingState() :
 	m_textAttributeBits(0),
 	m_fontSize(12.0/*WP6_DEFAULT_FONT_SIZE*/), // FIXME ME!!!!!!!!!!!!!!!!!!! HELP WP6_DEFAULT_FONT_SIZE
-	m_fontName(new WPXString(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman")), // EN PAS DEFAULT FONT AAN VOOR WP5/6/etc
+	m_fontName(new librevenge::RVNGString(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman")), // EN PAS DEFAULT FONT AAN VOOR WP5/6/etc
 	m_fontColor(new RGBSColor(0x00,0x00,0x00,0x64)), //Set default to black. Maybe once it will change, but for the while...
 	m_highlightColor(0),
 
@@ -120,14 +119,14 @@ _WPXContentParsingState::_WPXContentParsingState() :
 {
 }
 
-_WPXContentParsingState::~_WPXContentParsingState()
+WPXContentParsingState::~WPXContentParsingState()
 {
 	DELETEP(m_fontName);
 	DELETEP(m_fontColor);
 	DELETEP(m_highlightColor);
 }
 
-WPXContentListener::WPXContentListener(std::list<WPXPageSpan> &pageList, WPXDocumentInterface *documentInterface) :
+WPXContentListener::WPXContentListener(std::list<WPXPageSpan> &pageList, librevenge::RVNGTextInterface *documentInterface) :
 	WPXListener(pageList),
 	m_ps(new WPXContentParsingState),
 	m_documentInterface(documentInterface),
@@ -144,12 +143,12 @@ void WPXContentListener::startDocument()
 {
 	if (!m_ps->m_isDocumentStarted)
 	{
+		m_documentInterface->startDocument(librevenge::RVNGPropertyList());
+
 		// FIXME: this is stupid, we should store a property list filled with the relevant metadata
 		// and then pass that directly..
-
 		m_documentInterface->setDocumentMetaData(m_metaData);
 
-		m_documentInterface->startDocument();
 	}
 
 	m_ps->m_isDocumentStarted = true;
@@ -202,31 +201,33 @@ void WPXContentListener::_openSection()
 		if (!m_ps->m_isPageSpanOpened)
 			_openPageSpan();
 
-		WPXPropertyList propList;
+		librevenge::RVNGPropertyList propList;
 
 		propList.insert("fo:margin-left", m_ps->m_sectionMarginLeft);
 		propList.insert("fo:margin-right", m_ps->m_sectionMarginRight);
 		if (m_ps->m_numColumns > 1)
 		{
-			propList.insert("libwpd:margin-bottom", 1.0);
+			propList.insert("librevenge:margin-bottom", 1.0);
 			propList.insert("text:dont-balance-text-columns", false);
 		}
 		else
-			propList.insert("libwpd:margin-bottom", 0.0);
+			propList.insert("librevenge:margin-bottom", 0.0);
 
-		WPXPropertyListVector columns;
+		librevenge::RVNGPropertyListVector columns;
 		typedef std::vector<WPXColumnDefinition>::const_iterator CDVIter;
 		for (CDVIter iter = m_ps->m_textColumns.begin(); iter != m_ps->m_textColumns.end(); ++iter)
 		{
-			WPXPropertyList column;
+			librevenge::RVNGPropertyList column;
 			// The "style:rel-width" is expressed in twips (1440 twips per inch) and includes the left and right Gutter
-			column.insert("style:rel-width", (*iter).m_width * 1440.0, WPX_TWIP);
+			column.insert("style:rel-width", (*iter).m_width * 1440.0, librevenge::RVNG_TWIP);
 			column.insert("fo:start-indent", (*iter).m_leftGutter);
 			column.insert("fo:end-indent", (*iter).m_rightGutter);
 			columns.append(column);
 		}
+		if (columns.count())
+			propList.insert("style:columns", columns);
 		if (!m_ps->m_isSectionOpened)
-			m_documentInterface->openSection(propList, columns);
+			m_documentInterface->openSection(propList);
 
 		m_ps->m_sectionAttributesChanged = false;
 		m_ps->m_isSectionOpened = true;
@@ -250,9 +251,9 @@ void WPXContentListener::_closeSection()
 	}
 }
 
-void WPXContentListener::_insertPageNumberParagraph(WPXPageNumberPosition position, WPXNumberingType numberingType, WPXString fontName, double fontSize)
+void WPXContentListener::_insertPageNumberParagraph(WPXPageNumberPosition position, WPXNumberingType numberingType, librevenge::RVNGString fontName, double fontSize)
 {
-	WPXPropertyList propList;
+	librevenge::RVNGPropertyList propList;
 	switch (position)
 	{
 	case PAGENUMBER_POSITION_TOP_LEFT:
@@ -276,17 +277,18 @@ void WPXContentListener::_insertPageNumberParagraph(WPXPageNumberPosition positi
 		break;
 	}
 
-	m_documentInterface->openParagraph(propList, WPXPropertyListVector());
+	m_documentInterface->openParagraph(propList);
 
 	propList.clear();
 	propList.insert("style:font-name", fontName.cstr());
-	propList.insert("fo:font-size", fontSize, WPX_POINT);
+	propList.insert("fo:font-size", fontSize, librevenge::RVNG_POINT);
 	m_documentInterface->openSpan(propList);
 
 
 	propList.clear();
 	propList.insert("style:num-format", _numberingTypeToString(numberingType));
-	m_documentInterface->insertField(WPXString("text:page-number"), propList);
+	propList.insert("librevenge:field-type", "text:page-number");
+	m_documentInterface->insertField(propList);
 
 	propList.clear();
 	m_documentInterface->closeSpan();
@@ -314,22 +316,22 @@ void WPXContentListener::_openPageSpan()
 	m_ps->m_listReferencePosition += m_ps->m_pageMarginLeft;
 	m_ps->m_listBeginPosition += m_ps->m_pageMarginLeft;
 
-	if ( m_pageList.empty() || (m_ps->m_currentPage >= m_pageList.size()) )
+	if (m_pageList.empty() || (m_ps->m_currentPage >= m_pageList.size()))
 	{
 		WPD_DEBUG_MSG(("m_pageList.empty() || (m_ps->m_currentPage >= m_pageList.size())\n"));
 		throw ParseException();
 	}
 
 	std::list<WPXPageSpan>::iterator currentPageSpanIter = m_pageList.begin();
-	for ( unsigned i = 0; i < m_ps->m_currentPage; i++ )
+	for (unsigned i = 0; i < m_ps->m_currentPage; i++)
 		++currentPageSpanIter;
 
 	WPXPageSpan currentPage = (*currentPageSpanIter);
 
-	WPXPropertyList propList;
-	propList.insert("libwpd:num-pages", currentPage.getPageSpan());
+	librevenge::RVNGPropertyList propList;
+	propList.insert("librevenge:num-pages", currentPage.getPageSpan());
 
-	propList.insert("libwpd:is-last-page-span", ((m_ps->m_currentPage + 1 == m_pageList.size()) ? true : false));
+	propList.insert("librevenge:is-last-page-span", ((m_ps->m_currentPage + 1 == m_pageList.size()) ? true : false));
 	propList.insert("fo:page-height", currentPage.getFormLength());
 	propList.insert("fo:page-width", currentPage.getFormWidth());
 	if (currentPage.getFormOrientation() == LANDSCAPE)
@@ -378,19 +380,19 @@ void WPXContentListener::_openPageSpan()
 	std::vector<WPXHeaderFooter> headerFooterList = currentPage.getHeaderFooterList();
 	for (std::vector<WPXHeaderFooter>::iterator iter = headerFooterList.begin(); iter != headerFooterList.end(); ++iter)
 	{
-		if (((*iter).getOccurence() != NEVER) && !currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
+		if (((*iter).getOccurrence() != NEVER) && !currentPage.getHeaderFooterSuppression((*iter).getInternalType()))
 		{
 			propList.clear();
-			switch ((*iter).getOccurence())
+			switch ((*iter).getOccurrence())
 			{
 			case ODD:
-				propList.insert("libwpd:occurence", "odd");
+				propList.insert("librevenge:occurrence", "odd");
 				break;
 			case EVEN:
-				propList.insert("libwpd:occurence", "even");
+				propList.insert("librevenge:occurrence", "even");
 				break;
 			case ALL:
-				propList.insert("libwpd:occurence", "all");
+				propList.insert("librevenge:occurrence", "all");
 				break;
 			case NEVER:
 			default:
@@ -431,8 +433,8 @@ void WPXContentListener::_openPageSpan()
 				m_documentInterface->closeFooter();
 			}
 
-			WPD_DEBUG_MSG(("Header Footer Element: type: %i occurence: %i\n",
-			               (*iter).getType(), (*iter).getOccurence()));
+			WPD_DEBUG_MSG(("Header Footer Element: type: %i occurrence: %i\n",
+			               (*iter).getType(), (*iter).getOccurrence()));
 		}
 	}
 
@@ -442,7 +444,7 @@ void WPXContentListener::_openPageSpan()
 		        currentPage.getPageNumberPosition() != PAGENUMBER_POSITION_TOP_INSIDE_LEFT_AND_RIGHT)
 		{
 			propList.clear();
-			propList.insert("libwpd:occurence", "all");
+			propList.insert("librevenge:occurrence", "all");
 			m_documentInterface->openFooter(propList);
 			_insertPageNumberParagraph(currentPage.getPageNumberPosition(), currentPage.getPageNumberingType(),
 			                           currentPage.getPageNumberingFontName(), currentPage.getPageNumberingFontSize());
@@ -451,7 +453,7 @@ void WPXContentListener::_openPageSpan()
 		else
 		{
 			propList.clear();
-			propList.insert("libwpd:occurence", "all");
+			propList.insert("librevenge:occurrence", "all");
 			m_documentInterface->openHeader(propList);
 			_insertPageNumberParagraph(currentPage.getPageNumberPosition(), currentPage.getPageNumberingType(),
 			                           currentPage.getPageNumberingFontName(), currentPage.getPageNumberingFontSize());
@@ -511,14 +513,16 @@ void WPXContentListener::_openParagraph()
 				_openSection();
 		}
 
-		WPXPropertyListVector tabStops;
+		librevenge::RVNGPropertyListVector tabStops;
 		_getTabStops(tabStops);
 
-		WPXPropertyList propList;
+		librevenge::RVNGPropertyList propList;
 		_appendParagraphProperties(propList);
+		if (tabStops.count())
+			propList.insert("style:tab-stops", tabStops);
 
 		if (!m_ps->m_isParagraphOpened)
-			m_documentInterface->openParagraph(propList, tabStops);
+			m_documentInterface->openParagraph(propList);
 
 		_resetParagraphState();
 		m_ps->m_firstParagraphInPageSpan = false;
@@ -553,7 +557,7 @@ void WPXContentListener::_resetParagraphState(const bool isListElement)
 	m_ps->m_listBeginPosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 }
 
-void WPXContentListener::_appendJustification(WPXPropertyList &propList, int justification)
+void WPXContentListener::_appendJustification(librevenge::RVNGPropertyList &propList, int justification)
 {
 	switch (justification)
 	{
@@ -579,7 +583,7 @@ void WPXContentListener::_appendJustification(WPXPropertyList &propList, int jus
 	}
 }
 
-void WPXContentListener::_appendParagraphProperties(WPXPropertyList &propList, const bool isListElement)
+void WPXContentListener::_appendParagraphProperties(librevenge::RVNGPropertyList &propList, const bool isListElement)
 {
 	int justification;
 	if (m_ps->m_tempParagraphJustification)
@@ -605,12 +609,12 @@ void WPXContentListener::_appendParagraphProperties(WPXPropertyList &propList, c
 	}
 	propList.insert("fo:margin-top", m_ps->m_paragraphMarginTop);
 	propList.insert("fo:margin-bottom", m_ps->m_paragraphMarginBottom);
-	propList.insert("fo:line-height", m_ps->m_paragraphLineSpacing, WPX_PERCENT);
+	propList.insert("fo:line-height", m_ps->m_paragraphLineSpacing, librevenge::RVNG_PERCENT);
 
 	if (!m_ps->m_inSubDocument && m_ps->m_firstParagraphInPageSpan)
 	{
 		std::list<WPXPageSpan>::iterator currentPageSpanIter = m_pageList.begin();
-		for ( unsigned i = 0; i < (unsigned)(m_ps->m_currentPage - 1); i+=(unsigned)(*currentPageSpanIter).getPageSpan())
+		for (unsigned i = 0; i < (unsigned)(m_ps->m_currentPage - 1); i+=(unsigned)(*currentPageSpanIter).getPageSpan())
 			++currentPageSpanIter;
 
 		WPXPageSpan currentPage = (*currentPageSpanIter);
@@ -621,16 +625,16 @@ void WPXContentListener::_appendParagraphProperties(WPXPropertyList &propList, c
 	_insertBreakIfNecessary(propList);
 }
 
-void WPXContentListener::_insertText(const WPXString &textBuffer)
+void WPXContentListener::_insertText(const librevenge::RVNGString &textBuffer)
 {
 	if (textBuffer.len() <= 0)
 		return;
 
-	WPXString tmpText;
+	librevenge::RVNGString tmpText;
 	const char ASCII_SPACE = 0x0020;
 
 	int numConsecutiveSpaces = 0;
-	WPXString::Iter i(textBuffer);
+	librevenge::RVNGString::Iter i(textBuffer);
 	for (i.rewind(); i.next();)
 	{
 		if (*(i()) == ASCII_SPACE)
@@ -657,7 +661,7 @@ void WPXContentListener::_insertText(const WPXString &textBuffer)
 	m_documentInterface->insertText(tmpText);
 }
 
-void WPXContentListener::_insertBreakIfNecessary(WPXPropertyList &propList)
+void WPXContentListener::_insertBreakIfNecessary(librevenge::RVNGPropertyList &propList)
 {
 	if (m_ps->m_isParagraphPageBreak && !m_ps->m_inSubDocument) // no hard page-breaks in subdocuments
 		propList.insert("fo:break-before", "page");
@@ -670,11 +674,11 @@ void WPXContentListener::_insertBreakIfNecessary(WPXPropertyList &propList)
 	}
 }
 
-void WPXContentListener::_getTabStops(WPXPropertyListVector &tabStops)
+void WPXContentListener::_getTabStops(librevenge::RVNGPropertyListVector &tabStops)
 {
 	for (unsigned i=0; i<m_ps->m_tabStops.size(); i++)
 	{
-		WPXPropertyList tmpTabStop;
+		librevenge::RVNGPropertyList tmpTabStop;
 
 		// type
 		switch (m_ps->m_tabStops[i].m_alignment)
@@ -698,7 +702,7 @@ void WPXContentListener::_getTabStops(WPXPropertyListVector &tabStops)
 		// leader character
 		if (m_ps->m_tabStops[i].m_leaderCharacter != 0x0000)
 		{
-			WPXString sLeader;
+			librevenge::RVNGString sLeader;
 			sLeader.sprintf("%c", m_ps->m_tabStops[i].m_leaderCharacter);
 			tmpTabStop.insert("style:leader-text", sLeader);
 			tmpTabStop.insert("style:leader-style", "solid");
@@ -755,14 +759,16 @@ void WPXContentListener::_openListElement()
 				_openSection();
 		}
 
-		WPXPropertyList propList;
+		librevenge::RVNGPropertyList propList;
 		_appendParagraphProperties(propList, true);
 
-		WPXPropertyListVector tabStops;
+		librevenge::RVNGPropertyListVector tabStops;
 		_getTabStops(tabStops);
+		if (tabStops.count())
+			propList.insert("style:tab-stops", tabStops);
 
 		if (!m_ps->m_isListElementOpened)
-			m_documentInterface->openListElement(propList, tabStops);
+			m_documentInterface->openListElement(propList);
 		_resetParagraphState(true);
 	}
 }
@@ -800,14 +806,14 @@ void WPXContentListener::_openSpan()
 
 	// The behaviour of WP6+ is following: if an attribute bit is set in the cell attributes, we cannot
 	// unset it; if it is set, we can set or unset it
-	uint32_t attributeBits = (m_ps->m_textAttributeBits | m_ps->m_cellAttributeBits);
-	uint8_t fontSizeAttributes;
+	unsigned attributeBits = (m_ps->m_textAttributeBits | m_ps->m_cellAttributeBits);
+	unsigned char fontSizeAttributes;
 	double fontSizeChange;
 	// the font size attribute bits are mutually exclusive and the cell attributes prevail
 	if ((m_ps->m_cellAttributeBits & 0x0000001f) != 0x00000000)
-		fontSizeAttributes = (uint8_t)(m_ps->m_cellAttributeBits & 0x0000001f);
+		fontSizeAttributes = (unsigned char)(m_ps->m_cellAttributeBits & 0x0000001f);
 	else
-		fontSizeAttributes = (uint8_t)(m_ps->m_textAttributeBits & 0x0000001f);
+		fontSizeAttributes = (unsigned char)(m_ps->m_textAttributeBits & 0x0000001f);
 	switch (fontSizeAttributes)
 	{
 	case 0x01:  // Extra large
@@ -830,17 +836,17 @@ void WPXContentListener::_openSpan()
 		break;
 	}
 
-	WPXPropertyList propList;
+	librevenge::RVNGPropertyList propList;
 	if (attributeBits & WPX_SUPERSCRIPT_BIT)
 	{
-		WPXString sSuperScript("super ");
+		librevenge::RVNGString sSuperScript("super ");
 		sSuperScript.append(doubleToString(WPX_DEFAULT_SUPER_SUB_SCRIPT));
 		sSuperScript.append("%");
 		propList.insert("style:text-position", sSuperScript);
 	}
 	else if (attributeBits & WPX_SUBSCRIPT_BIT)
 	{
-		WPXString sSubScript("sub ");
+		librevenge::RVNGString sSubScript("sub ");
 		sSubScript.append(doubleToString(WPX_DEFAULT_SUPER_SUB_SCRIPT));
 		sSubScript.append("%");
 		propList.insert("style:text-position", sSubScript);
@@ -850,11 +856,20 @@ void WPXContentListener::_openSpan()
 	if (attributeBits & WPX_BOLD_BIT)
 		propList.insert("fo:font-weight", "bold");
 	if (attributeBits & WPX_STRIKEOUT_BIT)
+	{
 		propList.insert("style:text-line-through-type", "single");
+		propList.insert("style:text-line-through-style", "solid");
+	}
 	if (attributeBits & WPX_DOUBLE_UNDERLINE_BIT)
+	{
 		propList.insert("style:text-underline-type", "double");
+		propList.insert("style:text-underline-style", "solid");
+	}
 	else if (attributeBits & WPX_UNDERLINE_BIT)
+	{
 		propList.insert("style:text-underline-type", "single");
+		propList.insert("style:text-underline-style", "solid");
+	}
 	if (attributeBits & WPX_OUTLINE_BIT)
 		propList.insert("style:text-outline", "true");
 	if (attributeBits & WPX_SMALL_CAPS_BIT)
@@ -867,7 +882,7 @@ void WPXContentListener::_openSpan()
 	if (m_ps->m_fontName)
 		propList.insert("style:font-name", m_ps->m_fontName->cstr());
 
-	propList.insert("fo:font-size", fontSizeChange*m_ps->m_fontSize, WPX_POINT);
+	propList.insert("fo:font-size", fontSizeChange*m_ps->m_fontSize, librevenge::RVNG_POINT);
 
 	// Here we give the priority to the redline bit over the font color. This is how WordPerfect behaves:
 	// redline overrides font color even if the color is changed when redline was already defined.
@@ -901,7 +916,7 @@ void WPXContentListener::_openTable()
 {
 	_closeTable();
 
-	WPXPropertyList propList;
+	librevenge::RVNGPropertyList propList;
 	switch (m_ps->m_tableDefinition.m_positionBits)
 	{
 	case WPX_TABLE_POSITION_ALIGN_WITH_LEFT_MARGIN:
@@ -934,11 +949,11 @@ void WPXContentListener::_openTable()
 	m_ps->m_isParagraphPageBreak = false;
 
 	double tableWidth = 0.0;
-	WPXPropertyListVector columns;
+	librevenge::RVNGPropertyListVector columns;
 	typedef std::vector<WPXColumnDefinition>::const_iterator CDVIter;
 	for (CDVIter iter = m_ps->m_tableDefinition.m_columns.begin(); iter != m_ps->m_tableDefinition.m_columns.end(); ++iter)
 	{
-		WPXPropertyList column;
+		librevenge::RVNGPropertyList column;
 		// The "style:rel-width" is expressed in twips (1440 twips per inch) and includes the left and right Gutter
 		column.insert("style:column-width", (*iter).m_width);
 		columns.append(column);
@@ -946,8 +961,9 @@ void WPXContentListener::_openTable()
 		tableWidth += (*iter).m_width;
 	}
 	propList.insert("style:width", tableWidth);
+	propList.insert("librevenge:table-columns", columns);
 
-	m_documentInterface->openTable(propList, columns);
+	m_documentInterface->openTable(propList);
 	m_ps->m_isTableOpened = true;
 
 	m_ps->m_currentTableRow = (-1);
@@ -996,7 +1012,7 @@ void WPXContentListener::_openTableRow(const double height, const bool isMinimum
 	m_ps->m_currentTableCellNumberInRow = 0;
 
 
-	WPXPropertyList propList;
+	librevenge::RVNGPropertyList propList;
 	if (isMinimumHeight && height != 0.0) // minimum height kind of stupid if it's not set, right?
 		propList.insert("style:min-row-height", height);
 	else if (height != 0.0) // this indicates that wordperfect didn't set a height
@@ -1006,11 +1022,11 @@ void WPXContentListener::_openTableRow(const double height, const bool isMinimum
 	// The following "Header Row" flags are ignored
 	if (isHeaderRow & !m_ps->m_wasHeaderRow)
 	{
-		propList.insert("libwpd:is-header-row", true);
+		propList.insert("librevenge:is-header-row", true);
 		m_ps->m_wasHeaderRow = true;
 	}
 	else
-		propList.insert("libwpd:is-header-row", false);
+		propList.insert("librevenge:is-header-row", false);
 
 	m_documentInterface->openTableRow(propList);
 
@@ -1045,7 +1061,7 @@ void WPXContentListener::_closeTableRow()
 		if (m_ps->m_isRowWithoutCell)
 		{
 			m_ps->m_isRowWithoutCell = false;
-			WPXPropertyList tmpBlankList;
+			librevenge::RVNGPropertyList tmpBlankList;
 			m_documentInterface->insertCoveredTableCell(tmpBlankList);
 		}
 		m_documentInterface->closeTableRow();
@@ -1055,7 +1071,7 @@ void WPXContentListener::_closeTableRow()
 
 const double WPX_DEFAULT_TABLE_BORDER_WIDTH = 0.0007f;
 
-static void addBorderProps(const char *border, bool borderOn, const WPXString &borderColor, WPXPropertyList &propList)
+static void addBorderProps(const char *border, bool borderOn, const librevenge::RVNGString &borderColor, librevenge::RVNGPropertyList &propList)
 {
 #if 0
 // WLACH: a (not working, obviously) sketch of an alternate way of doing this
@@ -1072,9 +1088,9 @@ static void addBorderProps(const char *border, bool borderOn, const WPXString &b
 		propList.insert("fo:border-left-width", 0.0);
 #endif
 
-	WPXString borderStyle;
+	librevenge::RVNGString borderStyle;
 	borderStyle.sprintf("fo:border-%s", border);
-	WPXString props;
+	librevenge::RVNGString props;
 	if (borderOn)
 	{
 		props.append(doubleToString(WPX_DEFAULT_TABLE_BORDER_WIDTH));
@@ -1086,14 +1102,14 @@ static void addBorderProps(const char *border, bool borderOn, const WPXString &b
 	propList.insert(borderStyle.cstr(), props);
 }
 
-void WPXContentListener::_openTableCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits,
+void WPXContentListener::_openTableCell(const unsigned char colSpan, const unsigned char rowSpan, const unsigned char borderBits,
                                         const RGBSColor *cellFgColor, const RGBSColor *cellBgColor,
                                         const RGBSColor *cellBorderColor, const WPXVerticalAlignment cellVerticalAlignment)
 {
 	if (!m_ps->m_isTableOpened || !m_ps->m_isTableRowOpened)
 		throw ParseException();
 
-	uint8_t tmpColSpan = colSpan;
+	unsigned char tmpColSpan = colSpan;
 	if (m_ps->m_isTableCellOpened)
 		_closeTableCell();
 
@@ -1107,14 +1123,14 @@ void WPXContentListener::_openTableCell(const uint8_t colSpan, const uint8_t row
 		m_ps->m_currentTableCol++;
 	}
 
-	WPXPropertyList propList;
-	propList.insert("libwpd:column", m_ps->m_currentTableCol);
-	propList.insert("libwpd:row", m_ps->m_currentTableRow);
+	librevenge::RVNGPropertyList propList;
+	propList.insert("librevenge:column", m_ps->m_currentTableCol);
+	propList.insert("librevenge:row", m_ps->m_currentTableRow);
 
 	propList.insert("table:number-columns-spanned", colSpan);
 	propList.insert("table:number-rows-spanned", rowSpan);
 
-	WPXString borderColor = _colorToString(cellBorderColor);
+	librevenge::RVNGString borderColor = _colorToString(cellBorderColor);
 	addBorderProps("left", !(borderBits & WPX_TABLE_CELL_LEFT_BORDER_OFF), borderColor, propList);
 	addBorderProps("right", !(borderBits & WPX_TABLE_CELL_RIGHT_BORDER_OFF), borderColor, propList);
 	addBorderProps("top", !(borderBits & WPX_TABLE_CELL_TOP_BORDER_OFF), borderColor, propList);
@@ -1181,7 +1197,7 @@ void WPXContentListener::_closeTableCell()
 Creates an new document state. Saves the old state on a "stack".
 */
 void WPXContentListener::handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
-        WPXTableList tableList, unsigned nextTableIndice)
+                                           WPXTableList tableList, unsigned nextTableIndice)
 {
 	// save our old parsing state on our "stack"
 	WPXContentParsingState *oldPS = m_ps;
@@ -1228,7 +1244,7 @@ void WPXContentListener::handleSubDocument(const WPXSubDocument *subDocument, WP
 	m_ps = oldPS;
 }
 
-void WPXContentListener::insertBreak(const uint8_t breakType)
+void WPXContentListener::insertBreak(const unsigned char breakType)
 {
 	if (!isUndoOn())
 	{
@@ -1253,7 +1269,7 @@ void WPXContentListener::insertBreak(const uint8_t breakType)
 				_closeListElement();
 			m_ps->m_isParagraphPageBreak = true;
 			break;
-			// TODO: (.. line break?)
+		// TODO: (.. line break?)
 		default:
 			break;
 		}
@@ -1290,7 +1306,7 @@ void WPXContentListener::lineSpacingChange(const double lineSpacing)
 	}
 }
 
-void WPXContentListener::justificationChange(const uint8_t justification)
+void WPXContentListener::justificationChange(const unsigned char justification)
 {
 	if (!isUndoOn())
 	{
@@ -1366,9 +1382,9 @@ double WPXContentListener::_getPreviousTabStop() const
 	return (std::numeric_limits<double>::max)();
 }
 
-WPXString WPXContentListener::_colorToString(const RGBSColor *color)
+librevenge::RVNGString WPXContentListener::_colorToString(const RGBSColor *color)
 {
-	WPXString tmpString;
+	librevenge::RVNGString tmpString;
 
 	if (color)
 	{
@@ -1385,10 +1401,10 @@ WPXString WPXContentListener::_colorToString(const RGBSColor *color)
 	return tmpString;
 }
 
-WPXString WPXContentListener::_mergeColorsToString(const RGBSColor *fgColor,
-        const RGBSColor * /* bgColor */)
+librevenge::RVNGString WPXContentListener::_mergeColorsToString(const RGBSColor *fgColor,
+                                                                const RGBSColor * /* bgColor */)
 {
-	WPXString tmpColor;
+	librevenge::RVNGString tmpColor;
 	RGBSColor tmpFgColor, tmpBgColor;
 
 	if (fgColor)
@@ -1436,7 +1452,7 @@ double WPXContentListener::_movePositionToFirstColumn(double position)
 	return position;
 }
 
-uint32_t WPXContentListener::_mapNonUnicodeCharacter(uint32_t character)
+unsigned WPXContentListener::_mapNonUnicodeCharacter(unsigned character)
 {
 	if (*(m_ps->m_fontName) == "Symbol")
 		return _mapSymbolFontCharacter(character);
@@ -1447,11 +1463,11 @@ uint32_t WPXContentListener::_mapNonUnicodeCharacter(uint32_t character)
 	return character;
 }
 
-uint32_t WPXContentListener::_mapSymbolFontCharacter(uint32_t character)
+unsigned WPXContentListener::_mapSymbolFontCharacter(unsigned character)
 {
 	if (character >= 0x0020 && character <= 0x7E)
 	{
-		static const uint32_t _symbolFontMap1 [] =
+		static const unsigned _symbolFontMap1 [] =
 		{
 			0x0020, 0x0021, 0x2200, 0x0023, 0x2203, 0x0025, 0x0026, 0x220D, // 0x20 ..
 			0x0028, 0x0029, 0x2217, 0x002B, 0x002C, 0x2212, 0x002E, 0x002F,
@@ -1471,7 +1487,7 @@ uint32_t WPXContentListener::_mapSymbolFontCharacter(uint32_t character)
 	}
 	if (character >= 0x00A0 && character <= 0xFE)
 	{
-		static const uint32_t _symbolFontMap2 [] =
+		static const unsigned _symbolFontMap2 [] =
 		{
 			0x20AC, 0x03D2, 0x2032, 0x2264, 0x2044, 0x221E, 0x0192, 0x2663, // 0xA0 ..
 			0x2666, 0x2665, 0x2660, 0x2194, 0x2190, 0x2191, 0x2192, 0x2193,
@@ -1492,11 +1508,11 @@ uint32_t WPXContentListener::_mapSymbolFontCharacter(uint32_t character)
 	return character;
 }
 
-uint32_t WPXContentListener::_mapDingbatsFontCharacter(uint32_t character)
+unsigned WPXContentListener::_mapDingbatsFontCharacter(unsigned character)
 {
 	if (character >= 0x20 && character <= 0x7E)
 	{
-		static const uint32_t _dingbatsFontMap1 [] =
+		static const unsigned _dingbatsFontMap1 [] =
 		{
 			0x0020, 0x2701, 0x2702, 0x2703, 0x2704, 0x260E, 0x2706, 0x2707, // 0x20 ..
 			0x2708, 0x2709, 0x261B, 0x261E, 0x270C, 0x270D, 0x270E, 0x270F,
@@ -1516,7 +1532,7 @@ uint32_t WPXContentListener::_mapDingbatsFontCharacter(uint32_t character)
 	}
 	if (character >= 0x80 && character <= 0x8D)
 	{
-		static const uint32_t _dingbatsFontMap2 [] =
+		static const unsigned _dingbatsFontMap2 [] =
 		{
 			0x2768, 0x2769, 0x276A, 0x276B, 0x276C, 0x276D, 0x276E, 0x276F, // 0x80 ..
 			0x2770, 0x2771, 0x2772, 0x2773, 0x2774, 0x2775                  // .. 0x8D
@@ -1526,7 +1542,7 @@ uint32_t WPXContentListener::_mapDingbatsFontCharacter(uint32_t character)
 	}
 	if (character >= 0xA1 && character <= 0xEF)
 	{
-		static const uint32_t _dingbatsFontMap3 [] =
+		static const unsigned _dingbatsFontMap3 [] =
 		{
 			0x2761, 0x2762, 0x2763, 0x2764, 0x2765, 0x2766, 0x2767, 0x2663, // 0xA1 ..
 			0x2666, 0x2665, 0x2660, 0x2460, 0x2461, 0x2462, 0x2463, 0x2464,
@@ -1544,7 +1560,7 @@ uint32_t WPXContentListener::_mapDingbatsFontCharacter(uint32_t character)
 	}
 	if (character >= 0xF1 && character <=0xFE)
 	{
-		static const uint32_t _dingbatsFontMap4 [] =
+		static const unsigned _dingbatsFontMap4 [] =
 		{
 			0x27B1, 0x27B2, 0x27B3, 0x27B4, 0x27B5, 0x27B6, 0x27B7, 0x27B8, // 0xF1 ..
 			0x27B9, 0x27BA, 0x27BB, 0x27BC, 0x27BD, 0x27BE                  // .. OxFE
